#
import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats import resolve_label_ar
from ArWikiCats.new.resolve_films_bots.resolve_films_labels_and_time import fetch_films_by_category

data_0 = {
    "Superhero television characters by franchise": "أبطال خارقون تلفازيون حسب حق الامتياز",
    "DC Comics superhero teams": "فرق أبطال دي سي كومكس",
    "Superhero film series navigational boxes": "صناديق تصفح سلاسل أفلام أبطال خارقين",
    "Superheroes": "أبطال خارقون",
    "Superheroes in anime and manga": "أنمي ومانغا أبطال خارقين",
    "Superheroes by publisher": "أبطال خارقون حسب الناشر",
    "Superheroes by type": "أبطال خارقون حسب النوع",
    "Animal superheroes": "حيوانات أبطال خارقين",
    "Child superheroes": "أبطال خارقون أطفال",
    "Comics superheroes": "قصص مصورة حول أبطال خارقون",
    "DC Comics female superheroes": "بطلات دي سي كومكس الخارقات",
    "DC Comics superheroes": "أبطال دي سي كومكس",
    "Egyptian superheroes": "أبطال خارقون مصريون",
    "Golden Age superheroes": "أبطال العصر الذهبي",
    "Marvel Comics female superheroes": "بطلات مارفل كومكس الخارقات",
    "Marvel Comics superheroes": "أبطال خارقون في مارفل كومكس",
    "Muslim superheroes": "أبطال خارقون مسلمون",
}

data_to_fix1 = {
    "Lists of superhero films": "قوائم أفلام أبطال خارقين",
    "Superhero films about Asian Americans": "أفلام أبطال خارقين عن أمريكيون آسيويون",
    "Superhero television series by country": "مسلسلات تلفزيونية أبطال خارقين حسب البلد",
    "Superhero television series by genre": "مسلسلات تلفزيونية أبطال خارقين حسب النوع الفني",
    "Superhero comedy films by century": "أفلام أبطال خارقين كوميدية حسب القرن",
    "Animated superhero films by decade": "أفلام رسوم متحركة أبطال خارقين حسب العقد",
    "American superhero comedy television series by decade": "مسلسلات تلفزيونية أبطال خارقين كوميدية أمريكية حسب العقد",
    "Superhero films by century": "أفلام أبطال خارقين حسب القرن",
    "Superhero films by country": "أفلام أبطال خارقين حسب البلد",
    "Superhero films by decade": "أفلام أبطال خارقين حسب العقد",
    "Superhero films by genre": "أفلام أبطال خارقين حسب النوع الفني",
    "Superhero comedy films by decade": "أفلام أبطال خارقين كوميدية حسب العقد",
}

data_to_fix2 = {
    "1950s American superhero television series": "مسلسلات تلفزيونية أبطال خارقين أمريكية في عقد 1950",
    "1960s American superhero comedy television series": "مسلسلات تلفزيونية أبطال خارقين كوميدية أمريكية في عقد 1960",
    "1970s American superhero television series": "مسلسلات تلفزيونية أبطال خارقين أمريكية في عقد 1970",
    "1980s American superhero television series": "مسلسلات تلفزيونية أبطال خارقين أمريكية في عقد 1980",
    "1990s American superhero comedy television series": "مسلسلات تلفزيونية أبطال خارقين كوميدية أمريكية في عقد 1990",
    "1990s American superhero television series": "مسلسلات تلفزيونية أبطال خارقين أمريكية في عقد 1990",
    "1990s animated superhero films": "أفلام رسوم متحركة أبطال خارقين في عقد 1990",
    "2000s American superhero comedy television series": "مسلسلات تلفزيونية أبطال خارقين كوميدية أمريكية في عقد 2000",
    "2000s American superhero television series": "مسلسلات تلفزيونية أبطال خارقين أمريكية في عقد 2000",
    "2000s animated superhero films": "أفلام رسوم متحركة أبطال خارقين في عقد 2000",
    "2010s American superhero comedy television series": "مسلسلات تلفزيونية أبطال خارقين كوميدية أمريكية في عقد 2010",
    "2010s American superhero television series": "مسلسلات تلفزيونية أبطال خارقين أمريكية في عقد 2010",
    "2010s animated superhero films": "أفلام رسوم متحركة أبطال خارقين في عقد 2010",
    "2010s animated superhero television films": "أفلام تلفزيونية رسوم متحركة أبطال خارقين في عقد 2010",
    "2020s American superhero comedy television series": "مسلسلات تلفزيونية أبطال خارقين كوميدية أمريكية في عقد 2020",
    "2020s American superhero television series": "مسلسلات تلفزيونية أبطال خارقين أمريكية في عقد 2020",
    "2020s animated superhero films": "أفلام رسوم متحركة أبطال خارقين في عقد 2020",
    "2024 superhero films": "أفلام أبطال خارقين في 2024",
    "20th-century superhero comedy films": "أفلام أبطال خارقين كوميدية في القرن 20",
    "21st-century superhero comedy films": "أفلام أبطال خارقين كوميدية في القرن 21",
    "Adult animated superhero films": "أفلام رسوم متحركة للكبار أبطال خارقين",
    "African-American superhero films": "أفلام أبطال خارقين أمريكية إفريقية",
    "American adult animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة للكبار أبطال خارقين أمريكية",
    "American animated superhero films": "أفلام رسوم متحركة أبطال خارقين أمريكية",
    "American animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة أبطال خارقين أمريكية",
    "American black superhero television shows": "عروض تلفزيونية سوداء أبطال خارقين أمريكية",
    "American superhero comedy television series": "مسلسلات تلفزيونية أبطال خارقين كوميدية أمريكية",
    "American superhero television series": "مسلسلات تلفزيونية أبطال خارقين أمريكية",
    "Animated superhero films": "أفلام رسوم متحركة أبطال خارقين",
    "Animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة أبطال خارقين",
    "Brazilian adult animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة للكبار أبطال خارقين برازيلية",
    "British superhero films": "أفلام أبطال خارقين بريطانية",
    "British superhero television series": "مسلسلات تلفزيونية أبطال خارقين بريطانية",
    "Canadian superhero comedy television series": "مسلسلات تلفزيونية أبطال خارقين كوميدية كندية",
    "Canadian superhero films": "أفلام أبطال خارقين كندية",
    "Canadian superhero television series": "مسلسلات تلفزيونية أبطال خارقين كندية",
    "Chinese superhero films": "أفلام أبطال خارقين صينية",
    "French superhero films": "أفلام أبطال خارقين فرنسية",
    "German superhero films": "أفلام أبطال خارقين ألمانية",
    "Indian superhero films": "أفلام أبطال خارقين هندية",
    "Indian superhero television shows": "عروض تلفزيونية أبطال خارقين هندية",
    "Italian superhero films": "أفلام أبطال خارقين إيطالية",
    "Japanese adult animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة للكبار أبطال خارقين يابانية",
    "Japanese animated superhero films": "أفلام رسوم متحركة أبطال خارقين يابانية",
    "Japanese animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة أبطال خارقين يابانية",
    "LGBTQ-related superhero films": "أفلام أبطال خارقين متعلقة بإل جي بي تي كيو",
    "LGBTQ-related superhero television shows": "عروض تلفزيونية أبطال خارقين متعلقة بإل جي بي تي كيو",
    "Russian superhero films": "أفلام أبطال خارقين روسية",
    "Saudi Arabian superhero films": "أفلام أبطال خارقين سعودية",
    "Superhero comedy television series": "مسلسلات تلفزيونية أبطال خارقين كوميدية",
    "Superhero comic strips": "شرائط كومكس أبطال خارقين",
    "Superhero comics": "قصص مصورة أبطال خارقين",
    "Superhero film characters": "شخصيات أفلام أبطال خارقين",
    "Superhero games": "ألعاب أبطال خارقين",
    "Superhero horror comics": "قصص مصورة أبطال خارقين رعب",
    "Superhero horror films": "أفلام أبطال خارقين رعب",
    "Superhero horror television shows": "عروض تلفزيونية أبطال خارقين رعب",
    "Superhero novels": "روايات أبطال خارقين",
    "Superhero science fiction web series": "مسلسلات ويب أبطال خارقين خيال علمي",
    "Superhero television characters": "شخصيات تلفزيونية أبطال خارقين",
    "Superhero television episodes": "حلقات تلفزيونية أبطال خارقين",
    "Superhero television series": "مسلسلات تلفزيونية أبطال خارقين",
    "Superhero television shows": "عروض تلفزيونية أبطال خارقين",
    "Superhero thriller films": "أفلام أبطال خارقين إثارة",
    "Superhero video games": "ألعاب فيديو أبطال خارقين",
    "Superhero web series": "مسلسلات ويب أبطال خارقين",
    "Superhero webcomics": "ويب كومكس أبطال خارقين",
    "Teen superhero films": "أفلام مراهقة أبطال خارقين",
    "Teen superhero television series": "مسلسلات تلفزيونية مراهقة أبطال خارقين",
    "1940s superhero films": "أفلام أبطال خارقين في عقد 1940",
    "1960s superhero films": "أفلام أبطال خارقين في عقد 1960",
    "1970s superhero films": "أفلام أبطال خارقين في عقد 1970",
    "1980s superhero comedy films": "أفلام أبطال خارقين كوميدية في عقد 1980",
    "1980s superhero films": "أفلام أبطال خارقين في عقد 1980",
    "1990s superhero comedy films": "أفلام أبطال خارقين كوميدية في عقد 1990",
    "1990s superhero films": "أفلام أبطال خارقين في عقد 1990",
    "2000s superhero comedy films": "أفلام أبطال خارقين كوميدية في عقد 2000",
    "2000s superhero films": "أفلام أبطال خارقين في عقد 2000",
    "2010s superhero comedy films": "أفلام أبطال خارقين كوميدية في عقد 2010",
    "2010s superhero films": "أفلام أبطال خارقين في عقد 2010",
    "2020s superhero comedy films": "أفلام أبطال خارقين كوميدية في عقد 2020",
    "2020s superhero films": "أفلام أبطال خارقين في عقد 2020",
    "20th-century superhero films": "أفلام أبطال خارقين في القرن 20",
    "21st-century superhero films": "أفلام أبطال خارقين في القرن 21",
    "American superhero comedy films": "أفلام أبطال خارقين كوميدية أمريكية",
    "American superhero films": "أفلام أبطال خارقين أمريكية",
    "Czech superhero films": "أفلام أبطال خارقين تشيكية",
    "Hong Kong superhero films": "أفلام أبطال خارقين هونغ كونغية",
    "Indonesian superhero films": "أفلام أبطال خارقين إندونيسية",
    "Japanese superhero films": "أفلام أبطال خارقين يابانية",
    "Superhero adventure films": "أفلام أبطال خارقين مغامرات",
    "Superhero black comedy films": "أفلام أبطال خارقين كوميدية سوداء",
    "Superhero comedy-drama films": "أفلام أبطال خارقين كوميدية درامية",
    "Superhero comedy films": "أفلام أبطال خارقين كوميدية",
    "Superhero drama films": "أفلام أبطال خارقين درامية",
    # "Superhero films": "أفلام أبطال خارقين",
    "Superhero teams": "فرق أبطال خارقين",
}

data_to_fix3 = {
    "American children's animated superhero films": "أفلام رسوم متحركة أبطال خارقين أمريكية للأطفال",
    "American children's animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة أبطال خارقين أمريكية للأطفال",
    "Australian children's animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة أبطال خارقين أسترالية للأطفال",
    "British children's animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة أبطال خارقين بريطانية للأطفال",
    "Canadian children's animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة أبطال خارقين كندية للأطفال",
    "Danish children's animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة أبطال خارقين دنماركية للأطفال",
    "French children's animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة أبطال خارقين فرنسية للأطفال",
    "Italian children's animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة أبطال خارقين إيطالية للأطفال",
    "Japanese children's animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة أبطال خارقين يابانية للأطفال",
    "South Korean children's animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة أبطال خارقين كورية جنوبية للأطفال",
    "Spanish children's animated superhero television series": "مسلسلات تلفزيونية رسوم متحركة أبطال خارقين إسبانية للأطفال",
}

to_test = [
    # ("test_superhero_data_1", data_2),
    # ("test_superhero_data_3", data_3),
    # ("test_superhero_data_to_fix1", data_0, resolve_label_ar),
    ("test_superhero_data_to_fix2", data_to_fix2, fetch_films_by_category),
    ("test_superhero_data_to_fix3", data_to_fix3, fetch_films_by_category),
]


@pytest.mark.parametrize("category, expected", data_to_fix2.items(), ids=data_to_fix2.keys())
def test_superhero_data_2(category: str, expected: str) -> None:
    result = fetch_films_by_category(category)
    assert result == expected


@pytest.mark.parametrize("category, expected", data_to_fix3.items(), ids=data_to_fix3.keys())
def test_superhero_data_3(category: str, expected: str) -> None:
    result = fetch_films_by_category(category)
    assert result == expected


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)

    # dump_diff_text (expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""
!
"""

import functools

from ...helps import logger
from ...new_resolvers.reslove_all import new_resolvers_all
from ...new_resolvers.resolve_languages import resolve_languages_labels
from ...time_resolvers.time_to_arabic import convert_time_to_arabic
from ...translations import Ambassadors_tab, People_key, get_from_new_p17_final
from .. import team_work, with_years_bot
from ..films_and_others_bot import te_films
from ..ma_bots2 import year_or_typeo
from ..make_bots.bot_2018 import get_pop_All_18
from ..o_bots import univer
from ..o_bots.peoples_resolver import work_peoples
from . import ye_ts_bot
from .country_bot import event2_d2


@functools.lru_cache(maxsize=None)
def event_label_work(target_category: str) -> str:
    """Retrieve category lab information based on the provided category.

    This function attempts to find the corresponding category lab for a
    given category string by checking multiple sources in a specific order.
    It first normalizes the input category string and then queries various
    data sources to retrieve the relevant information. If no match is found,
    it attempts to find a wikidata entry based on the category string.

    Args:
        target_category (str): The category string for which the lab information is sought.

    Returns:
        str: The corresponding category lab information or an empty string if not
            found.
    """

    normalized_target_category = target_category.lower().strip()

    if normalized_target_category == "people":
        return "أشخاص"

    logger.info("<<lightblue>>>> vvvvvvvvvvvv event_label_work start vvvvvvvvvvvv ")
    logger.info(f"<<lightyellow>>>>>> {normalized_target_category=}")

    resolved_category_label = (
        get_from_new_p17_final(normalized_target_category, "")
        or Ambassadors_tab.get(normalized_target_category, "")
        or team_work.Get_team_work_Club(normalized_target_category)
        or univer.te_universities(normalized_target_category)
        or event2_d2(normalized_target_category)
        or with_years_bot.Try_With_Years2(normalized_target_category)
        or year_or_typeo.label_for_startwith_year_or_typeo(normalized_target_category)
        or get_pop_All_18(normalized_target_category, "")
        or convert_time_to_arabic(normalized_target_category)
        or new_resolvers_all(normalized_target_category)
        or resolve_languages_labels(normalized_target_category)
        or People_key.get(normalized_target_category)
        or univer.te_universities(normalized_target_category)
        or te_films(normalized_target_category)
        or ye_ts_bot.translate_general_category(normalized_target_category)
        or work_peoples(normalized_target_category)
        or ""
    )

    return resolved_category_label



#
import pytest
from load_one_data import dump_diff, dump_diff_text, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data1 = {}

data2 = {
    "Category:1964 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1964",
    "Category:1972 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1972",
    "Category:2003 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 2003",
    "Category:2026 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2026",
    "Category:american women's sports": "تصنيف:رياضات نسائية أمريكية",
    "Category:canadian women's sports": "تصنيف:رياضات نسائية كندية",
    "Category:mexican women's sports": "تصنيف:رياضات نسائية مكسيكية",
    "Category:1550 in sports": "تصنيف:ألعاب رياضية في 1550",
    "Category:december 1550 in sports": "تصنيف:ألعاب رياضية في ديسمبر 1550",
    "Category:june 1550 in sports": "تصنيف:ألعاب رياضية في يونيو 1550",
    "Category:Sports leagues in Papua New Guinea": "تصنيف:دوريات رياضية في بابوا غينيا الجديدة",
    "Category:honduran people in sports": "تصنيف:هندوراسيون في ألعاب رياضية",
    "Category:Jewish sports": "تصنيف:ألعاب رياضية يهودية",
    "Category:surinamese sports federation": "تصنيف:الاتحاد السورينامي للرياضة",
    "Category:zaïrean wheelchair sports federation": "تصنيف:الاتحاد الزائيري للرياضة على الكراسي المتحركة",
    "Category:American women's sports by year": "تصنيف:رياضات نسائية أمريكية حسب السنة",
    "Category:American women's sports by decade": "تصنيف:رياضات نسائية أمريكية حسب العقد",
    "Category:1887 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1887",
    "Category:1889 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1889",
    "Category:1930 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1930",
    "Category:1931 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1931",
    "Category:1934 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1934",
    "Category:1938 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1938",
    "Category:1945 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1945",
    "Category:1946 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1946",
    "Category:1947 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1947",
    "Category:1948 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1948",
    "Category:1950 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1950",
    "Category:1951 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1951",
    "Category:1953 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1953",
    "Category:1954 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1954",
    "Category:1955 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1955",
    "Category:1956 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1956",
    "Category:1959 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1959",
    "Category:1961 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1961",
    "Category:1963 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1963",
    "Category:1966 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1966",
    "Category:1967 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1967",
    "Category:1968 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1968",
    "Category:1970 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1970",
    "Category:1971 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1971",
    "Category:1973 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1973",
    "Category:1974 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1974",
    "Category:1975 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1975",
    "Category:1978 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1978",
    "Category:1979 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1979",
    "Category:1980 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1980",
    "Category:1982 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1982",
    "Category:1983 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1983",
    "Category:1984 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1984",
    "Category:1985 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1985",
    "Category:1986 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1986",
    "Category:1987 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1987",
    "Category:1989 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1989",
    "Category:1990 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1990",
    "Category:1991 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1991",
    "Category:1992 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1992",
    "Category:1993 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1993",
    "Category:1995 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1995",
    "Category:1996 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1996",
    "Category:1998 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1998",
    "Category:2000 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2000",
    "Category:2001 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2001",
    "Category:2004 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2004",
    "Category:2005 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2005",
    "Category:2006 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2006",
    "Category:2007 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2007",
    "Category:2009 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2009",
    "Category:2010 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2010",
    "Category:2011 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2011",
    "Category:2012 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2012",
    "Category:2013 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2013",
    "Category:2014 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2014",
    "Category:2015 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2015",
    "Category:2016 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2016",
    "Category:2017 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2017",
    "Category:2018 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2018",
    "Category:2021 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2021",
    "Category:2022 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2022",
    "Category:2023 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2023",
    "Category:2024 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2024",
    "Category:2025 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2025",
    "Category:1880s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1880",
    "Category:1930s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1930",
    "Category:1940s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1940",
    "Category:1950s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1950",
    "Category:1960s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1960",
    "Category:1970s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1970",
    "Category:1980s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1980",
    "Category:1990s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1990",
    "Category:2010s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 2010",
    "Category:2020s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 2020",
    "Category:Canadian women's sports by year": "تصنيف:رياضات نسائية كندية حسب السنة",
    "Category:Canadian women's sports by decade": "تصنيف:رياضات نسائية كندية حسب العقد",
    "Category:1983 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 1983",
    "Category:2004 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 2004",
    "Category:2007 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 2007",
    "Category:2011 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 2011",
    "Category:2012 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 2012",
    "Category:2023 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 2023",
    "Category:1980s in Canadian women's sports": "تصنيف:رياضات نسائية كندية في عقد 1980",
    "Category:1990s in Canadian women's sports": "تصنيف:رياضات نسائية كندية في عقد 1990",
    "Category:2000s in Canadian women's sports": "تصنيف:رياضات نسائية كندية في عقد 2000",
    "Category:2010s in Canadian women's sports": "تصنيف:رياضات نسائية كندية في عقد 2010",
    "Category:2020s in Canadian women's sports": "تصنيف:رياضات نسائية كندية في عقد 2020",
    "Category:Mexican women's sports by year": "تصنيف:رياضات نسائية مكسيكية حسب السنة",
    "Category:Mexican women's sports by decade": "تصنيف:رياضات نسائية مكسيكية حسب العقد",
    "Category:1971 in Mexican women's sports": "تصنيف:رياضات نسائية مكسيكية في 1971",
    "Category:1974 in Mexican women's sports": "تصنيف:رياضات نسائية مكسيكية في 1974",
    "Category:2010 in Mexican women's sports": "تصنيف:رياضات نسائية مكسيكية في 2010",
    "Category:1970s in Mexican women's sports": "تصنيف:رياضات نسائية مكسيكية في عقد 1970",
    "Category:2010s in Mexican women's sports": "تصنيف:رياضات نسائية مكسيكية في عقد 2010",
}

data3 = {
    "Category:Documentary films about women's sports": "تصنيف:أفلام وثائقية عن رياضات نسائية",
    "Category:History of women's sports": "تصنيف:تاريخ رياضات نسائية",
    "Category:Women's sports by dependent territory": "تصنيف:رياضات نسائية حسب الأقاليم التابعة",
    "Category:Women's sports by populated place": "تصنيف:رياضات نسائية حسب المكان المأهول",
    "Category:Women's sports by sport and country": "تصنيف:رياضات نسائية حسب الرياضة والبلد",
    "Category:Women's sports by year": "تصنيف:رياضات نسائية حسب السنة",
    "Category:Women's sports in American Samoa": "تصنيف:رياضات نسائية في ساموا الأمريكية",
    "Category:Women's sports in Arizona": "تصنيف:رياضات نسائية في أريزونا",
    "Category:Women's sports in Atlanta": "تصنيف:رياضات نسائية في أتلانتا (جورجيا)",
    "Category:Women's sports in Boston": "تصنيف:رياضات نسائية في بوسطن",
    "Category:Women's sports in Botswana": "تصنيف:رياضات نسائية في بوتسوانا",
    "Category:Women's sports in British Columbia": "تصنيف:رياضات نسائية في كولومبيا البريطانية",
    "Category:Women's sports in California": "تصنيف:رياضات نسائية في كاليفورنيا",
    "Category:Women's sports in Canada": "تصنيف:رياضات نسائية في كندا",
    "Category:Women's sports in Charlotte, North Carolina": "تصنيف:رياضات نسائية في تشارلوت (كارولاينا الشمالية)",
    "Category:Women's sports in Chicago": "تصنيف:رياضات نسائية في شيكاغو",
    "Category:Women's sports in Cleveland": "تصنيف:رياضات نسائية في كليفلاند",
    "Category:Women's sports in Connecticut": "تصنيف:رياضات نسائية في كونيتيكت",
    "Category:Women's sports in Dallas": "تصنيف:رياضات نسائية في دالاس",
    "Category:Women's sports in Detroit": "تصنيف:رياضات نسائية في ديترويت",
    "Category:Women's sports in Florida": "تصنيف:رياضات نسائية في فلوريدا",
    "Category:Women's sports in Georgia (U.S. state)": "تصنيف:رياضات نسائية في ولاية جورجيا",
    "Category:Women's sports in Guam": "تصنيف:رياضات نسائية في غوام",
    "Category:Women's sports in Haryana": "تصنيف:رياضات نسائية في هاريانا",
    "Category:Women's sports in Houston": "تصنيف:رياضات نسائية في هيوستن",
    "Category:Women's sports in Illinois": "تصنيف:رياضات نسائية في إلينوي",
    "Category:Women's sports in Indiana": "تصنيف:رياضات نسائية في إنديانا",
    "Category:Women's sports in insular areas of the United States": "تصنيف:رياضات نسائية في المناطق المعزولة في الولايات المتحدة",
    "Category:Women's sports in Iowa": "تصنيف:رياضات نسائية في آيوا",
    "Category:Women's sports in Istanbul": "تصنيف:رياضات نسائية في إسطنبول",
    "Category:Women's sports in Kansas": "تصنيف:رياضات نسائية في كانساس",
    "Category:Women's sports in Kansas City, Missouri": "تصنيف:رياضات نسائية في كانساس سيتي (ميزوري)",
    "Category:Women's sports in Kentucky": "تصنيف:رياضات نسائية في كنتاكي",
    "Category:Women's sports in Lebanon": "تصنيف:رياضات نسائية في لبنان",
    "Category:Women's sports in Los Angeles": "تصنيف:رياضات نسائية في لوس أنجلوس",
    "Category:Women's sports in Louisiana": "تصنيف:رياضات نسائية في لويزيانا",
    "Category:Women's sports in Manitoba": "تصنيف:رياضات نسائية في مانيتوبا",
    "Category:Women's sports in Maryland": "تصنيف:رياضات نسائية في ماريلند",
    "Category:Women's sports in Massachusetts": "تصنيف:رياضات نسائية في ماساتشوستس",
    "Category:Women's sports in Miami": "تصنيف:رياضات نسائية في ميامي",
    "Category:Women's sports in Michigan": "تصنيف:رياضات نسائية في ميشيغان",
    "Category:Women's sports in Minnesota": "تصنيف:رياضات نسائية في منيسوتا",
    "Category:Women's sports in Missouri": "تصنيف:رياضات نسائية في ميزوري",
    "Category:Women's sports in Nevada": "تصنيف:رياضات نسائية في نيفادا",
    "Category:Women's sports in New Jersey": "تصنيف:رياضات نسائية في نيوجيرسي",
    "Category:Women's sports in New York (state)": "تصنيف:رياضات نسائية في ولاية نيويورك",
    "Category:Women's sports in New York City": "تصنيف:رياضات نسائية في مدينة نيويورك",
    "Category:Women's sports in North America": "تصنيف:رياضات نسائية في أمريكا الشمالية",
    "Category:Women's sports in North Carolina": "تصنيف:رياضات نسائية في كارولاينا الشمالية",
    "Category:Women's sports in Nova Scotia": "تصنيف:رياضات نسائية في نوفا سكوشا",
    "Category:Women's sports in Oceania": "تصنيف:رياضات نسائية في أوقيانوسيا",
    "Category:Women's sports in Ohio": "تصنيف:رياضات نسائية في أوهايو",
    "Category:Women's sports in Oklahoma": "تصنيف:رياضات نسائية في أوكلاهوما",
    "Category:Women's sports in Pennsylvania": "تصنيف:رياضات نسائية في بنسلفانيا",
    "Category:Women's sports in Philadelphia": "تصنيف:رياضات نسائية في فيلادلفيا",
    "Category:Women's sports in Puerto Rico": "تصنيف:رياضات نسائية في بورتوريكو",
    "Category:Women's sports in Quebec": "تصنيف:رياضات نسائية في كيبك",
    "Category:Women's sports in Quebec City": "تصنيف:رياضات نسائية في مدينة كيبك",
    "Category:Women's sports in Rhode Island": "تصنيف:رياضات نسائية في رود آيلاند",
    "Category:Women's sports in San Diego": "تصنيف:رياضات نسائية في سان دييغو",
    "Category:Women's sports in Seattle": "تصنيف:رياضات نسائية في سياتل",
    "Category:Women's sports in South Carolina": "تصنيف:رياضات نسائية في كارولاينا الجنوبية",
    "Category:Women's sports in Texas": "تصنيف:رياضات نسائية في تكساس",
    "Category:Women's sports in the Philippines": "تصنيف:رياضات نسائية في الفلبين",
    "Category:Women's sports in the United States": "تصنيف:رياضات نسائية في الولايات المتحدة",
    "Category:Women's sports in the United States by state": "تصنيف:رياضات نسائية في الولايات المتحدة حسب الولاية",
    "Category:Women's sports in Utah": "تصنيف:رياضات نسائية في يوتا",
    "Category:Women's sports in Vancouver": "تصنيف:رياضات نسائية في فانكوفر",
    "Category:Women's sports in West Germany": "تصنيف:رياضات نسائية في ألمانيا الغربية",
    "Category:Women's sports in Wisconsin": "تصنيف:رياضات نسائية في ويسكونسن",
    "Category:Works about women's sports": "تصنيف:أعمال عن رياضات نسائية",
    "Category:1884 in women's sport": "تصنيف:رياضة نسائية في 1884",
    "Category:1885 in women's sport": "تصنيف:رياضة نسائية في 1885",
    "Category:1886 in women's sport": "تصنيف:رياضة نسائية في 1886",
    "Category:1887 in women's sport": "تصنيف:رياضة نسائية في 1887",
    "Category:1888 in women's sport": "تصنيف:رياضة نسائية في 1888",
    "Category:1891 in women's sport": "تصنيف:رياضة نسائية في 1891",
    "Category:1892 in women's sport": "تصنيف:رياضة نسائية في 1892",
    "Category:1893 in women's sport": "تصنيف:رياضة نسائية في 1893",
    "Category:1894 in women's sport": "تصنيف:رياضة نسائية في 1894",
    "Category:1895 in women's sport": "تصنيف:رياضة نسائية في 1895",
    "Category:1896 in women's sport": "تصنيف:رياضة نسائية في 1896",
    "Category:1897 in women's sport": "تصنيف:رياضة نسائية في 1897",
    "Category:1901 in women's sport": "تصنيف:رياضة نسائية في 1901",
    "Category:1902 in women's sport": "تصنيف:رياضة نسائية في 1902",
    "Category:1903 in women's sport": "تصنيف:رياضة نسائية في 1903",
    "Category:1904 in women's sport": "تصنيف:رياضة نسائية في 1904",
    "Category:1905 in women's sport": "تصنيف:رياضة نسائية في 1905",
    "Category:1906 in women's sport": "تصنيف:رياضة نسائية في 1906",
    "Category:1907 in women's sport": "تصنيف:رياضة نسائية في 1907",
    "Category:1908 in women's sport": "تصنيف:رياضة نسائية في 1908",
    "Category:1909 in women's sport": "تصنيف:رياضة نسائية في 1909",
    "Category:1910 in women's sport": "تصنيف:رياضة نسائية في 1910",
    "Category:1911 in women's sport": "تصنيف:رياضة نسائية في 1911",
    "Category:1912 in women's sport": "تصنيف:رياضة نسائية في 1912",
    "Category:1913 in women's sport": "تصنيف:رياضة نسائية في 1913",
    "Category:1914 in women's sport": "تصنيف:رياضة نسائية في 1914",
    "Category:1919 in women's sport": "تصنيف:رياضة نسائية في 1919",
    "Category:1920 in women's sport": "تصنيف:رياضة نسائية في 1920",
    "Category:1921 in women's sport": "تصنيف:رياضة نسائية في 1921",
    "Category:1922 in women's sport": "تصنيف:رياضة نسائية في 1922",
    "Category:1923 in women's sport": "تصنيف:رياضة نسائية في 1923",
    "Category:1924 in women's sport": "تصنيف:رياضة نسائية في 1924",
    "Category:1926 in women's sport": "تصنيف:رياضة نسائية في 1926",
    "Category:1927 in women's sport": "تصنيف:رياضة نسائية في 1927",
    "Category:1928 in women's sport": "تصنيف:رياضة نسائية في 1928",
    "Category:1929 in women's sport": "تصنيف:رياضة نسائية في 1929",
    "Category:1930 in women's sport": "تصنيف:رياضة نسائية في 1930",
    "Category:1932 in women's sport": "تصنيف:رياضة نسائية في 1932",
    "Category:1933 in women's sport": "تصنيف:رياضة نسائية في 1933",
    "Category:1934 in women's sport": "تصنيف:رياضة نسائية في 1934",
    "Category:1936 in women's sport": "تصنيف:رياضة نسائية في 1936",
    "Category:1937 in women's sport": "تصنيف:رياضة نسائية في 1937",
    "Category:1946 in women's sport": "تصنيف:رياضة نسائية في 1946",
    "Category:1947 in women's sport": "تصنيف:رياضة نسائية في 1947",
    "Category:1948 in women's sport": "تصنيف:رياضة نسائية في 1948",
    "Category:1949 in women's sport": "تصنيف:رياضة نسائية في 1949",
    "Category:1950 in women's sport": "تصنيف:رياضة نسائية في 1950",
    "Category:1952 in women's sport": "تصنيف:رياضة نسائية في 1952",
    "Category:1953 in women's sport": "تصنيف:رياضة نسائية في 1953",
    "Category:1954 in women's sport": "تصنيف:رياضة نسائية في 1954",
    "Category:1956 in women's sport": "تصنيف:رياضة نسائية في 1956",
    "Category:1957 in women's sport": "تصنيف:رياضة نسائية في 1957",
    "Category:1959 in women's sport": "تصنيف:رياضة نسائية في 1959",
    "Category:1961 in women's sport": "تصنيف:رياضة نسائية في 1961",
    "Category:1963 in women's sport": "تصنيف:رياضة نسائية في 1963",
    "Category:1964 in women's sport": "تصنيف:رياضة نسائية في 1964",
    "Category:1965 in women's sport": "تصنيف:رياضة نسائية في 1965",
    "Category:1969 in women's sport": "تصنيف:رياضة نسائية في 1969",
    "Category:1970 in women's sport": "تصنيف:رياضة نسائية في 1970",
    "Category:1971 in women's sport": "تصنيف:رياضة نسائية في 1971",
    "Category:1972 in women's sport": "تصنيف:رياضة نسائية في 1972",
    "Category:1973 in women's sport": "تصنيف:رياضة نسائية في 1973",
    "Category:1974 in women's sport": "تصنيف:رياضة نسائية في 1974",
    "Category:1974 in women's sport by country": "تصنيف:رياضة نسائية في 1974 حسب البلد",
    "Category:1975 in women's sport": "تصنيف:رياضة نسائية في 1975",
    "Category:1976 in women's sport": "تصنيف:رياضة نسائية في 1976",
    "Category:1977 in women's sport": "تصنيف:رياضة نسائية في 1977",
    "Category:1978 in women's sport": "تصنيف:رياضة نسائية في 1978",
    "Category:1986 in women's sport by country": "تصنيف:رياضة نسائية في 1986 حسب البلد",
    "Category:1987 in women's sport by country": "تصنيف:رياضة نسائية في 1987 حسب البلد",
    "Category:1988 in women's sport": "تصنيف:رياضة نسائية في 1988",
    "Category:1988 in women's sport by country": "تصنيف:رياضة نسائية في 1988 حسب البلد",
    "Category:1989 in women's sport by country": "تصنيف:رياضة نسائية في 1989 حسب البلد",
    "Category:1990 in women's sport by country": "تصنيف:رياضة نسائية في 1990 حسب البلد",
    "Category:1991 in women's sport by country": "تصنيف:رياضة نسائية في 1991 حسب البلد",
    "Category:1992 in women's sport": "تصنيف:رياضة نسائية في 1992",
    "Category:1992 in women's sport by country": "تصنيف:رياضة نسائية في 1992 حسب البلد",
    "Category:1993 in women's sport by country": "تصنيف:رياضة نسائية في 1993 حسب البلد",
    "Category:1994 in women's sport by country": "تصنيف:رياضة نسائية في 1994 حسب البلد",
    "Category:1995 in women's sport by country": "تصنيف:رياضة نسائية في 1995 حسب البلد",
    "Category:1996 in women's sport by country": "تصنيف:رياضة نسائية في 1996 حسب البلد",
    "Category:1998 in women's sport by country": "تصنيف:رياضة نسائية في 1998 حسب البلد",
    "Category:1999 in women's sport by country": "تصنيف:رياضة نسائية في 1999 حسب البلد",
    "Category:2000 in women's sport by country": "تصنيف:رياضة نسائية في 2000 حسب البلد",
    "Category:2001 in women's sport by country": "تصنيف:رياضة نسائية في 2001 حسب البلد",
    "Category:2003 in women's sport by country": "تصنيف:رياضة نسائية في 2003 حسب البلد",
    "Category:2004 in women's sport by country": "تصنيف:رياضة نسائية في 2004 حسب البلد",
    "Category:2005 in women's sport by country": "تصنيف:رياضة نسائية في 2005 حسب البلد",
    "Category:2006 in women's sport by country": "تصنيف:رياضة نسائية في 2006 حسب البلد",
    "Category:2008 in women's sport by country": "تصنيف:رياضة نسائية في 2008 حسب البلد",
    "Category:2009 in women's sport by country": "تصنيف:رياضة نسائية في 2009 حسب البلد",
    "Category:2010 in women's sport": "تصنيف:رياضة نسائية في 2010",
    "Category:2010 in women's sport by country": "تصنيف:رياضة نسائية في 2010 حسب البلد",
    "Category:2013 in women's sport by country": "تصنيف:رياضة نسائية في 2013 حسب البلد",
    "Category:2014 in women's sport": "تصنيف:رياضة نسائية في 2014",
    "Category:2014 in women's sport by country": "تصنيف:رياضة نسائية في 2014 حسب البلد",
    "Category:2015 in women's sport": "تصنيف:رياضة نسائية في 2015",
    "Category:2015 in women's sport by country": "تصنيف:رياضة نسائية في 2015 حسب البلد",
    "Category:2017 in women's sport by country": "تصنيف:رياضة نسائية في 2017 حسب البلد",
    "Category:2018 in women's sport": "تصنيف:رياضة نسائية في 2018",
    "Category:2018 in women's sport by country": "تصنيف:رياضة نسائية في 2018 حسب البلد",
    "Category:2019 in women's sport by country": "تصنيف:رياضة نسائية في 2019 حسب البلد",
    "Category:Women's sport-related lists": "تصنيف:قوائم متعلقة برياضة نسائية",
    "Category:Women's sport by country and year": "تصنيف:رياضة نسائية حسب البلد والسنة",
    "Category:Women's sport by year and country": "تصنيف:رياضة نسائية حسب السنة والبلد",
    "Category:Women's sport in Afghanistan": "تصنيف:رياضة نسائية في أفغانستان",
    "Category:Women's sport in Albania": "تصنيف:رياضة نسائية في ألبانيا",
    "Category:Women's sport in Algeria": "تصنيف:رياضة نسائية في الجزائر",
    "Category:Women's sport in Amsterdam": "تصنيف:رياضة نسائية في أمستردام",
    "Category:Women's sport in Andorra": "تصنيف:رياضة نسائية في أندورا",
    "Category:Women's sport in Angola": "تصنيف:رياضة نسائية في أنغولا",
    "Category:Women's sport in Antigua and Barbuda": "تصنيف:رياضة نسائية في أنتيغوا وباربودا",
    "Category:Women's sport in Argentina": "تصنيف:رياضة نسائية في الأرجنتين",
    "Category:Women's sport in Armenia": "تصنيف:رياضة نسائية في أرمينيا",
    "Category:Women's sport in Aruba": "تصنيف:رياضة نسائية في أروبا",
    "Category:Women's sport in Australia": "تصنيف:رياضة نسائية في أستراليا",
    "Category:Women's sport in Austria": "تصنيف:رياضة نسائية في النمسا",
    "Category:Women's sport in Azerbaijan": "تصنيف:رياضة نسائية في أذربيجان",
    "Category:Women's sport in Bangladesh": "تصنيف:رياضة نسائية في بنغلاديش",
    "Category:Women's sport in Barbados": "تصنيف:رياضة نسائية في بربادوس",
    "Category:Women's sport in Belarus": "تصنيف:رياضة نسائية في روسيا البيضاء",
    "Category:Women's sport in Belgium": "تصنيف:رياضة نسائية في بلجيكا",
    "Category:Women's sport in Belize": "تصنيف:رياضة نسائية في بليز",
    "Category:Women's sport in Benin": "تصنيف:رياضة نسائية في بنين",
    "Category:Women's sport in Bermuda": "تصنيف:رياضة نسائية في برمودا",
    "Category:Women's sport in Bhutan": "تصنيف:رياضة نسائية في بوتان",
    "Category:Women's sport in Bolivia": "تصنيف:رياضة نسائية في بوليفيا",
    "Category:Women's sport in Bosnia and Herzegovina": "تصنيف:رياضة نسائية في البوسنة والهرسك",
    "Category:Women's sport in Botswana": "تصنيف:رياضة نسائية في بوتسوانا",
    "Category:Women's sport in Brazil": "تصنيف:رياضة نسائية في البرازيل",
    "Category:Women's sport in Brunei": "تصنيف:رياضة نسائية في بروناي",
    "Category:Women's sport in Bulgaria": "تصنيف:رياضة نسائية في بلغاريا",
    "Category:Women's sport in Cambodia": "تصنيف:رياضة نسائية في كمبوديا",
    "Category:Women's sport in Cameroon": "تصنيف:رياضة نسائية في الكاميرون",
    "Category:Women's sport in Central America": "تصنيف:رياضة نسائية في أمريكا الوسطى",
    "Category:Women's sport in Chile": "تصنيف:رياضة نسائية في تشيلي",
    "Category:Women's sport in China": "تصنيف:رياضة نسائية في الصين",
    "Category:Women's sport in Costa Rica": "تصنيف:رياضة نسائية في كوستاريكا",
    "Category:Women's sport in Croatia": "تصنيف:رياضة نسائية في كرواتيا",
    "Category:Women's sport in Cuba": "تصنيف:رياضة نسائية في كوبا",
    "Category:Women's sport in Cyprus": "تصنيف:رياضة نسائية في قبرص",
    "Category:Women's sport in Czechoslovakia": "تصنيف:رياضة نسائية في تشيكوسلوفاكيا",
    "Category:Women's sport in dependent territories of the United Kingdom": "تصنيف:رياضة نسائية في أقاليم ما وراء البحار البريطانية",
    "Category:Women's sport in Djibouti": "تصنيف:رياضة نسائية في جيبوتي",
    "Category:Women's sport in East Germany": "تصنيف:رياضة نسائية في ألمانيا الشرقية",
    "Category:Women's sport in Ecuador": "تصنيف:رياضة نسائية في الإكوادور",
    "Category:Women's sport in Egypt": "تصنيف:رياضة نسائية في مصر",
    "Category:Women's sport in El Salvador": "تصنيف:رياضة نسائية في السلفادور",
    "Category:Women's sport in England": "تصنيف:رياضة نسائية في إنجلترا",
    "Category:Women's sport in Equatorial Guinea": "تصنيف:رياضة نسائية في غينيا الاستوائية",
    "Category:Women's sport in Estonia": "تصنيف:رياضة نسائية في إستونيا",
    "Category:Women's sport in Ethiopia": "تصنيف:رياضة نسائية في إثيوبيا",
    "Category:Women's sport in Fiji": "تصنيف:رياضة نسائية في فيجي",
    "Category:Women's sport in Finland": "تصنيف:رياضة نسائية في فنلندا",
    "Category:Women's sport in France": "تصنيف:رياضة نسائية في فرنسا",
    "Category:Women's sport in French Guiana": "تصنيف:رياضة نسائية في غويانا الفرنسية",
    "Category:Women's sport in Gabon": "تصنيف:رياضة نسائية في الغابون",
    "Category:Women's sport in Georgia (country)": "تصنيف:رياضة نسائية في جورجيا",
    "Category:Women's sport in Germany": "تصنيف:رياضة نسائية في ألمانيا",
    "Category:Women's sport in Ghana": "تصنيف:رياضة نسائية في غانا",
    "Category:Women's sport in Gibraltar": "تصنيف:رياضة نسائية في جبل طارق",
    "Category:Women's sport in Greenland": "تصنيف:رياضة نسائية في جرينلاند",
    "Category:Women's sport in Grenada": "تصنيف:رياضة نسائية في غرينادا",
    "Category:Women's sport in Guadeloupe": "تصنيف:رياضة نسائية في غوادلوب",
    "Category:Women's sport in Guatemala": "تصنيف:رياضة نسائية في غواتيمالا",
    "Category:Women's sport in Guinea": "تصنيف:رياضة نسائية في غينيا",
    "Category:Women's sport in Guyana": "تصنيف:رياضة نسائية في غيانا",
    "Category:Women's sport in Haiti": "تصنيف:رياضة نسائية في هايتي",
    "Category:Women's sport in Hong Kong": "تصنيف:رياضة نسائية في هونغ كونغ",
    "Category:Women's sport in Hungary": "تصنيف:رياضة نسائية في المجر",
    "Category:Women's sport in Iceland": "تصنيف:رياضة نسائية في آيسلندا",
    "Category:Women's sport in India": "تصنيف:رياضة نسائية في الهند",
    "Category:Women's sport in Indonesia": "تصنيف:رياضة نسائية في إندونيسيا",
    "Category:Women's sport in Iran": "تصنيف:رياضة نسائية في إيران",
    "Category:Women's sport in Iraq": "تصنيف:رياضة نسائية في العراق",
    "Category:Women's sport in Ireland": "تصنيف:رياضة نسائية في أيرلندا",
    "Category:Women's sport in Ireland by sport": "تصنيف:رياضة نسائية في أيرلندا حسب الرياضة",
    "Category:Women's sport in Israel": "تصنيف:رياضة نسائية في إسرائيل",
    "Category:Women's sport in Italy": "تصنيف:رياضة نسائية في إيطاليا",
    "Category:Women's sport in Ivory Coast": "تصنيف:رياضة نسائية في ساحل العاج",
    "Category:Women's sport in Jamaica": "تصنيف:رياضة نسائية في جامايكا",
    "Category:Women's sport in Japan": "تصنيف:رياضة نسائية في اليابان",
    "Category:Women's sport in Jordan": "تصنيف:رياضة نسائية في الأردن",
    "Category:Women's sport in Kazakhstan": "تصنيف:رياضة نسائية في كازاخستان",
    "Category:Women's sport in Kenya": "تصنيف:رياضة نسائية في كينيا",
    "Category:Women's sport in Korea": "تصنيف:رياضة نسائية في كوريا",
    "Category:Women's sport in Kosovo": "تصنيف:رياضة نسائية في كوسوفو",
    "Category:Women's sport in Kuwait": "تصنيف:رياضة نسائية في الكويت",
    "Category:Women's sport in Kyrgyzstan": "تصنيف:رياضة نسائية في قيرغيزستان",
    "Category:Women's sport in Laos": "تصنيف:رياضة نسائية في لاوس",
    "Category:Women's sport in Latvia": "تصنيف:رياضة نسائية في لاتفيا",
    "Category:Women's sport in Lebanon": "تصنيف:رياضة نسائية في لبنان",
    "Category:Women's sport in Lesotho": "تصنيف:رياضة نسائية في ليسوتو",
    "Category:Women's sport in Liberia": "تصنيف:رياضة نسائية في ليبيريا",
    "Category:Women's sport in Libya": "تصنيف:رياضة نسائية في ليبيا",
    "Category:Women's sport in Liechtenstein": "تصنيف:رياضة نسائية في ليختنشتاين",
    "Category:Women's sport in Lithuania": "تصنيف:رياضة نسائية في ليتوانيا",
    "Category:Women's sport in London": "تصنيف:رياضة نسائية في لندن",
    "Category:Women's sport in Luxembourg": "تصنيف:رياضة نسائية في لوكسمبورغ",
    "Category:Women's sport in Macau": "تصنيف:رياضة نسائية في ماكاو",
    "Category:Women's sport in Madagascar": "تصنيف:رياضة نسائية في مدغشقر",
    "Category:Women's sport in Malawi": "تصنيف:رياضة نسائية في ملاوي",
    "Category:Women's sport in Malaysia": "تصنيف:رياضة نسائية في ماليزيا",
    "Category:Women's sport in Mali": "تصنيف:رياضة نسائية في مالي",
    "Category:Women's sport in Malta": "تصنيف:رياضة نسائية في مالطا",
    "Category:Women's sport in Mauritius": "تصنيف:رياضة نسائية في موريشيوس",
    "Category:Women's sport in Mexico": "تصنيف:رياضة نسائية في المكسيك",
    "Category:Women's sport in Moldova": "تصنيف:رياضة نسائية في مولدوفا",
    "Category:Women's sport in Monaco": "تصنيف:رياضة نسائية في موناكو",
    "Category:Women's sport in Mongolia": "تصنيف:رياضة نسائية في منغوليا",
    "Category:Women's sport in Montenegro": "تصنيف:رياضة نسائية في الجبل الأسود",
    "Category:Women's sport in Morocco": "تصنيف:رياضة نسائية في المغرب",
    "Category:Women's sport in Mozambique": "تصنيف:رياضة نسائية في موزمبيق",
    "Category:Women's sport in Myanmar": "تصنيف:رياضة نسائية في ميانمار",
    "Category:Women's sport in Namibia": "تصنيف:رياضة نسائية في ناميبيا",
    "Category:Women's sport in Nepal": "تصنيف:رياضة نسائية في نيبال",
    "Category:Women's sport in New Zealand": "تصنيف:رياضة نسائية في نيوزيلندا",
    "Category:Women's sport in Nicaragua": "تصنيف:رياضة نسائية في نيكاراغوا",
    "Category:Women's sport in Niger": "تصنيف:رياضة نسائية في النيجر",
    "Category:Women's sport in Nigeria": "تصنيف:رياضة نسائية في نيجيريا",
    "Category:Women's sport in North Korea": "تصنيف:رياضة نسائية في كوريا الشمالية",
    "Category:Women's sport in North Macedonia": "تصنيف:رياضة نسائية في مقدونيا الشمالية",
    "Category:Women's sport in Northern Ireland": "تصنيف:رياضة نسائية في أيرلندا الشمالية",
    "Category:Women's sport in Norway": "تصنيف:رياضة نسائية في النرويج",
    "Category:Women's sport in Oman": "تصنيف:رياضة نسائية في سلطنة عمان",
    "Category:Women's sport in Pakistan": "تصنيف:رياضة نسائية في باكستان",
    "Category:Women's sport in Palestine": "تصنيف:رياضة نسائية في فلسطين",
    "Category:Women's sport in Panama": "تصنيف:رياضة نسائية في بنما",
    "Category:Women's sport in Papua New Guinea": "تصنيف:رياضة نسائية في بابوا غينيا الجديدة",
    "Category:Women's sport in Paraguay": "تصنيف:رياضة نسائية في باراغواي",
    "Category:Women's sport in Peru": "تصنيف:رياضة نسائية في بيرو",
    "Category:Women's sport in Poland": "تصنيف:رياضة نسائية في بولندا",
    "Category:Women's sport in Portugal": "تصنيف:رياضة نسائية في البرتغال",
    "Category:Women's sport in Qatar": "تصنيف:رياضة نسائية في قطر",
    "Category:Women's sport in Romania": "تصنيف:رياضة نسائية في رومانيا",
    "Category:Women's sport in Russia": "تصنيف:رياضة نسائية في روسيا",
    "Category:Women's sport in Rwanda": "تصنيف:رياضة نسائية في رواندا",
    "Category:Women's sport in Samoa": "تصنيف:رياضة نسائية في ساموا",
    "Category:Women's sport in San Marino": "تصنيف:رياضة نسائية في سان مارينو",
    "Category:Women's sport in Scotland": "تصنيف:رياضة نسائية في إسكتلندا",
    "Category:Women's sport in Senegal": "تصنيف:رياضة نسائية في السنغال",
    "Category:Women's sport in Serbia": "تصنيف:رياضة نسائية في صربيا",
    "Category:Women's sport in Seychelles": "تصنيف:رياضة نسائية في سيشل",
    "Category:Women's sport in Singapore": "تصنيف:رياضة نسائية في سنغافورة",
    "Category:Women's sport in Slovakia": "تصنيف:رياضة نسائية في سلوفاكيا",
    "Category:Women's sport in Slovenia": "تصنيف:رياضة نسائية في سلوفينيا",
    "Category:Women's sport in Somalia": "تصنيف:رياضة نسائية في الصومال",
    "Category:Women's sport in South Africa": "تصنيف:رياضة نسائية في جنوب إفريقيا",
    "Category:Women's sport in South Korea": "تصنيف:رياضة نسائية في كوريا الجنوبية",
    "Category:Women's sport in South Sudan": "تصنيف:رياضة نسائية في جنوب السودان",
    "Category:Women's sport in Southeast Asia": "تصنيف:رياضة نسائية في جنوب شرق آسيا",
    "Category:Women's sport in Spain": "تصنيف:رياضة نسائية في إسبانيا",
    "Category:Women's sport in Sri Lanka": "تصنيف:رياضة نسائية في سريلانكا",
    "Category:Women's sport in Sudan": "تصنيف:رياضة نسائية في السودان",
    "Category:Women's sport in Switzerland": "تصنيف:رياضة نسائية في سويسرا",
    "Category:Women's sport in Syria": "تصنيف:رياضة نسائية في سوريا",
    "Category:Women's sport in Taiwan": "تصنيف:رياضة نسائية في تايوان",
    "Category:Women's sport in Tajikistan": "تصنيف:رياضة نسائية في طاجيكستان",
    "Category:Women's sport in Tanzania": "تصنيف:رياضة نسائية في تنزانيا",
    "Category:Women's sport in Thailand": "تصنيف:رياضة نسائية في تايلاند",
    "Category:Women's sport in the Bahamas": "تصنيف:رياضة نسائية في باهاماس",
    "Category:Women's sport in the Caribbean": "تصنيف:رياضة نسائية في الكاريبي",
    "Category:Women's sport in the Cayman Islands": "تصنيف:رياضة نسائية في جزر كايمان",
    "Category:Women's sport in the Central African Republic": "تصنيف:رياضة نسائية في جمهورية إفريقيا الوسطى",
    "Category:Women's sport in the Comoros": "تصنيف:رياضة نسائية في جزر القمر",
    "Category:Women's sport in the Czech Republic": "تصنيف:رياضة نسائية في التشيك",
    "Category:Women's sport in the Democratic Republic of the Congo": "تصنيف:رياضة نسائية في جمهورية الكونغو الديمقراطية",
    "Category:Women's sport in the Dominican Republic": "تصنيف:رياضة نسائية في جمهورية الدومينيكان",
    "Category:Women's sport in the Faroe Islands": "تصنيف:رياضة نسائية في جزر فارو",
    "Category:Women's sport in the Republic of Ireland": "تصنيف:رياضة نسائية في جمهورية أيرلندا",
    "Category:Women's sport in the Republic of the Congo": "تصنيف:رياضة نسائية في جمهورية الكونغو",
    "Category:Women's sport in the Soviet Union": "تصنيف:رياضة نسائية في الاتحاد السوفيتي",
    "Category:Women's sport in the United Arab Emirates": "تصنيف:رياضة نسائية في الإمارات العربية المتحدة",
    "Category:Women's sport in the United Kingdom": "تصنيف:رياضة نسائية في المملكة المتحدة",
    "Category:Women's sport in Togo": "تصنيف:رياضة نسائية في توغو",
    "Category:Women's sport in Trinidad and Tobago": "تصنيف:رياضة نسائية في ترينيداد وتوباغو",
    "Category:Women's sport in Tunisia": "تصنيف:رياضة نسائية في تونس",
    "Category:Women's sport in Turkey": "تصنيف:رياضة نسائية في تركيا",
    "Category:Women's sport in Turkmenistan": "تصنيف:رياضة نسائية في تركمانستان",
    "Category:Women's sport in Uganda": "تصنيف:رياضة نسائية في أوغندا",
    "Category:Women's sport in Ukraine": "تصنيف:رياضة نسائية في أوكرانيا",
    "Category:Women's sport in Uruguay": "تصنيف:رياضة نسائية في أوروغواي",
    "Category:Women's sport in Uzbekistan": "تصنيف:رياضة نسائية في أوزبكستان",
    "Category:Women's sport in Vanuatu": "تصنيف:رياضة نسائية في فانواتو",
    "Category:Women's sport in Venezuela": "تصنيف:رياضة نسائية في فنزويلا",
    "Category:Women's sport in Vietnam": "تصنيف:رياضة نسائية في فيتنام",
    "Category:Women's sport in Wales": "تصنيف:رياضة نسائية في ويلز",
    "Category:Women's sport in West Germany": "تصنيف:رياضة نسائية في ألمانيا الغربية",
    "Category:Women's sport in Yemen": "تصنيف:رياضة نسائية في اليمن",
    "Category:Women's sport in Yugoslavia": "تصنيف:رياضة نسائية في يوغسلافيا",
    "Category:Women's sport in Zambia": "تصنيف:رياضة نسائية في زامبيا",
    "Category:Women's sport in Zimbabwe": "تصنيف:رياضة نسائية في زيمبابوي",
    "Category:Women's sport navigational boxes": "تصنيف:صناديق تصفح رياضة نسائية",
    "Category:Women's sport templates": "تصنيف:قوالب رياضة نسائية",
    "Category:Women's sports clubs and teams in Afghanistan": "تصنيف:أندية وفرق رياضية نسائية في أفغانستان",
    "Category:Women's sports clubs and teams in Albania": "تصنيف:أندية وفرق رياضية نسائية في ألبانيا",
    "Category:Women's sports clubs and teams in Andorra": "تصنيف:أندية وفرق رياضية نسائية في أندورا",
    "Category:Women's sports clubs and teams in Armenia": "تصنيف:أندية وفرق رياضية نسائية في أرمينيا",
    "Category:Women's sports clubs and teams in Azerbaijan": "تصنيف:أندية وفرق رياضية نسائية في أذربيجان",
    "Category:Women's sports clubs and teams in Bangladesh": "تصنيف:أندية وفرق رياضية نسائية في بنغلاديش",
    "Category:Women's sports clubs and teams in Botswana": "تصنيف:أندية وفرق رياضية نسائية في بوتسوانا",
    "Category:Women's sports clubs and teams in Denmark": "تصنيف:أندية وفرق رياضية نسائية في الدنمارك",
    "Category:Women's sports clubs and teams in Fiji": "تصنيف:أندية وفرق رياضية نسائية في فيجي",
    "Category:Women's sports clubs and teams in Gabon": "تصنيف:أندية وفرق رياضية نسائية في الغابون",
    "Category:Women's sports clubs and teams in Georgia (country)": "تصنيف:أندية وفرق رياضية نسائية في جورجيا",
    "Category:Women's sports clubs and teams in Guatemala": "تصنيف:أندية وفرق رياضية نسائية في غواتيمالا",
    "Category:Women's sports clubs and teams in Guyana": "تصنيف:أندية وفرق رياضية نسائية في غيانا",
    "Category:Women's sports clubs and teams in Haiti": "تصنيف:أندية وفرق رياضية نسائية في هايتي",
    "Category:Women's sports clubs and teams in Hong Kong": "تصنيف:أندية وفرق رياضية نسائية في هونغ كونغ",
    "Category:Women's sports clubs and teams in Ivory Coast": "تصنيف:أندية وفرق رياضية نسائية في ساحل العاج",
    "Category:Women's sports clubs and teams in Kenya": "تصنيف:أندية وفرق رياضية نسائية في كينيا",
    "Category:Women's sports clubs and teams in Kosovo": "تصنيف:أندية وفرق رياضية نسائية في كوسوفو",
    "Category:Women's sports clubs and teams in Laos": "تصنيف:أندية وفرق رياضية نسائية في لاوس",
    "Category:Women's sports clubs and teams in Lebanon": "تصنيف:أندية وفرق رياضية نسائية في لبنان",
    "Category:Women's sports clubs and teams in Lesotho": "تصنيف:أندية وفرق رياضية نسائية في ليسوتو",
    "Category:Women's sports clubs and teams in Malawi": "تصنيف:أندية وفرق رياضية نسائية في ملاوي",
    "Category:Women's sports clubs and teams in Malaysia": "تصنيف:أندية وفرق رياضية نسائية في ماليزيا",
    "Category:Women's sports clubs and teams in Moldova": "تصنيف:أندية وفرق رياضية نسائية في مولدوفا",
    "Category:Women's sports clubs and teams in Montenegro": "تصنيف:أندية وفرق رياضية نسائية في الجبل الأسود",
    "Category:Women's sports clubs and teams in Morocco": "تصنيف:أندية وفرق رياضية نسائية في المغرب",
    "Category:Women's sports clubs and teams in Niger": "تصنيف:أندية وفرق رياضية نسائية في النيجر",
    "Category:Women's sports clubs and teams in Pakistan": "تصنيف:أندية وفرق رياضية نسائية في باكستان",
    "Category:Women's sports clubs and teams in Paraguay": "تصنيف:أندية وفرق رياضية نسائية في باراغواي",
    "Category:Women's sports clubs and teams in Rwanda": "تصنيف:أندية وفرق رياضية نسائية في رواندا",
    "Category:Women's sports clubs and teams in Singapore": "تصنيف:أندية وفرق رياضية نسائية في سنغافورة",
    "Category:Women's sports clubs and teams in Sri Lanka": "تصنيف:أندية وفرق رياضية نسائية في سريلانكا",
    "Category:Women's sports clubs and teams in Syria": "تصنيف:أندية وفرق رياضية نسائية في سوريا",
    "Category:Women's sports clubs and teams in Tajikistan": "تصنيف:أندية وفرق رياضية نسائية في طاجيكستان",
    "Category:Women's sports clubs and teams in the Cayman Islands": "تصنيف:أندية وفرق رياضية نسائية في جزر كايمان",
    "Category:Women's sports clubs and teams in the Central African Republic": "تصنيف:أندية وفرق رياضية نسائية في جمهورية إفريقيا الوسطى",
    "Category:Women's sports clubs and teams in the Dominican Republic": "تصنيف:أندية وفرق رياضية نسائية في جمهورية الدومينيكان",
    "Category:Women's sports clubs and teams in the Philippines": "تصنيف:أندية وفرق رياضية نسائية في الفلبين",
    "Category:Women's sports clubs and teams in Togo": "تصنيف:أندية وفرق رياضية نسائية في توغو",
    "Category:Women's sports clubs and teams in Trinidad and Tobago": "تصنيف:أندية وفرق رياضية نسائية في ترينيداد وتوباغو",
    "Category:Women's sports clubs and teams in Uganda": "تصنيف:أندية وفرق رياضية نسائية في أوغندا",
    "Category:Women's sports clubs and teams in Venezuela": "تصنيف:أندية وفرق رياضية نسائية في فنزويلا",
    "Category:Women's sports clubs and teams in Zambia": "تصنيف:أندية وفرق رياضية نسائية في زامبيا",
    "Category:Women's sports clubs and teams in Zimbabwe": "تصنيف:أندية وفرق رياضية نسائية في زيمبابوي",
    "Category:Women's sports in Indianapolis": "تصنيف:رياضات نسائية في إنديانابوليس",
    "Category:Women's sports in Minneapolis": "تصنيف:رياضات نسائية في مينيابوليس",
    "Category:Women's sports in Oregon": "تصنيف:رياضات نسائية في أوريغن",
    "Category:Women's sports in Palau": "تصنيف:رياضات نسائية في بالاو",
    "Category:Women's sports in Vienna": "تصنيف:رياضات نسائية في فيينا",
}

to_test = [
    ("test_sports_data_1", data1),
    ("test_sports_data_2", data2),
    ("test_sports_data_3", data3),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
def test_sports_data_1(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("category, expected", data2.items(), ids=data2.keys())
def test_sports_data_2(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("category, expected", data3.items(), ids=data3.keys())
def test_sports_data_3(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)
    # dump_same_and_not_same(data, diff_result, name, True)
    # dump_diff_text (expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

temporal_1 = {
    "Category:1950s criminal comedy films": "تصنيف:أفلام كوميديا الجريمة في عقد 1950",
    "Category:1960s black comedy films": "تصنيف:أفلام كوميدية سوداء في عقد 1960",
    "Category:1960s criminal comedy films": "تصنيف:أفلام كوميديا الجريمة في عقد 1960",
    "Category:1970s black comedy films": "تصنيف:أفلام كوميدية سوداء في عقد 1970",
    "Category:1970s criminal comedy films": "تصنيف:أفلام كوميديا الجريمة في عقد 1970",
    "Category:1980s black comedy films": "تصنيف:أفلام كوميدية سوداء في عقد 1980",
    "Category:1980s criminal comedy films": "تصنيف:أفلام كوميديا الجريمة في عقد 1980",
    "Category:00s establishments in the Roman Empire": "تصنيف:تأسيسات عقد 00 في الإمبراطورية الرومانية",
    "Category:1000 disestablishments by country": "تصنيف:انحلالات سنة 1000 حسب البلد",
    "Category:1000 disestablishments in Europe": "تصنيف:انحلالات سنة 1000 في أوروبا",
    "Category:1000s disestablishments in Asia": "تصنيف:انحلالات عقد 1000 في آسيا",
    "Category:13th century establishments in the Roman Empire": "تصنيف:تأسيسات القرن 13 في الإمبراطورية الرومانية",
    "Category:14th-century establishments in India": "تصنيف:تأسيسات القرن 14 في الهند",
    "Category:1902 films": "تصنيف:أفلام إنتاج 1902",
    "Category:1990s BC disestablishments in Asia": "تصنيف:انحلالات عقد 1990 ق م في آسيا",
    "Category:1990s disestablishments in Europe": "تصنيف:انحلالات عقد 1990 في أوروبا",
    "Category:1994–95 in European rugby union by country": "تصنيف:اتحاد الرجبي الأوروبي في 1994–95 حسب البلد",
    "Category:1st century BC": "تصنيف:القرن 1 ق م",
}

temporal_2 = {
    "Category:2000s films": "تصنيف:أفلام إنتاج عقد 2000",
    "Category:2000s in American cinema": "تصنيف:السينما الأمريكية في عقد 2000",
    "Category:2000s in film": "تصنيف:عقد 2000 في الأفلام",
    "Category:2006 Winter Paralympics events": "تصنيف:أحداث الألعاب البارالمبية الشتوية 2006",
    "Category:2006 establishments by country": "تصنيف:تأسيسات سنة 2006 حسب البلد",
    "Category:2006 in north korean sport": "تصنيف:رياضة كورية شمالية في 2006",
    "Category:2017 American television series debuts": "تصنيف:مسلسلات تلفزيونية أمريكية بدأ عرضها في 2017",
    "Category:2017 American television series endings": "تصنيف:مسلسلات تلفزيونية أمريكية انتهت في 2017",
    "Category:2017 events by country": "تصنيف:أحداث 2017 حسب البلد",
    "Category:2017 events": "تصنيف:أحداث 2017",
    "Category:2017 in Emirati football": "تصنيف:كرة القدم الإماراتية في 2017",
    "Category:2017–18 in Emirati football": "تصنيف:كرة القدم الإماراتية في 2017–18",
    "Category:2018 Summer Youth Olympics events": "تصنيف:أحداث الألعاب الأولمبية الشبابية الصيفية 2018",
    "Category:20th-century disestablishments in India": "تصنيف:انحلالات القرن 20 في الهند",
    "Category:21st century in film": "تصنيف:القرن 21 في الأفلام",
    "Category:21st-century films": "تصنيف:أفلام إنتاج القرن 21",
    "Category:440s bc": "تصنيف:عقد 440 ق م",
    "Category:440s": "تصنيف:عقد 440",
    "Category:977 by country": "تصنيف:977 حسب البلد",
    "Category:Airlines by year of establishment": "تصنيف:شركات طيران حسب سنة التأسيس",
    "Category:American cinema by decade": "تصنيف:السينما الأمريكية حسب العقد",
}

temporal_3 = {
    "Category:10th millennium in fiction": "تصنيف:الخيال في الألفية 10",
    "Category:1270s in the Holy Roman Empire": "تصنيف:الإمبراطورية الرومانية المقدسة في عقد 1270",
    "Category:19th-century actors by religion": "تصنيف:ممثلون في القرن 19 حسب الدين",
    "Category:19th-century people by religion": "تصنيف:أشخاص في القرن 19 حسب الدين",
    "Category:2000s in the United States by state": "تصنيف:الولايات المتحدة في عقد 2000 حسب الولاية",
    "Category:21st century in the Czech Republic": "تصنيف:التشيك في القرن 21",
    "Category:21st-century in Qatar": "تصنيف:قطر في القرن 21",
    "Category:Manufacturing companies established in the 2nd millennium": "تصنيف:شركات تصنيع أسست في الألفية 2",
}
temporal_4 = {
    "Category:Animals by year of formal description": "تصنيف:حيوانات حسب سنة الوصف",
    "Category:April 1983 events in Europe": "تصنيف:أحداث أبريل 1983 في أوروبا",
    "Category:Comics set in the 1st century BC": "تصنيف:قصص مصورة تقع أحداثها في القرن 1 ق م",
    "Category:Decades by country": "تصنيف:عقود حسب البلد",
    "Category:Decades in Oklahoma": "تصنيف:عقود في أوكلاهوما",
    "Category:Decades in the United States by state": "تصنيف:عقود في الولايات المتحدة حسب الولاية",
    "Category:Films set in the 21st century": "تصنيف:أفلام تقع أحداثها في القرن 21",
    "Category:Historical webcomics": "تصنيف:ويب كومكس تاريخية",
    "Category:July 2018 events by continent": "تصنيف:أحداث يوليو 2018 حسب القارة",
    "Category:Mammals by century of formal description": "تصنيف:ثدييات حسب قرن الوصف",
    "Category:Multi-sport events in the Soviet Union": "تصنيف:أحداث رياضية متعددة في الاتحاد السوفيتي",
    # "Category:November 2006 in Yemen": "تصنيف:نوفمبر 2006 في اليمن",
    "Category:Olympic figure skaters by year": "تصنيف:متزلجون فنيون أولمبيون حسب السنة",
    "Category:Publications by year of disestablishment": "تصنيف:منشورات حسب سنة الانحلال",
    "Category:Publications by year of establishment": "تصنيف:منشورات حسب سنة التأسيس",
    "Category:Sports organisations by decade of establishment": "تصنيف:منظمات رياضية حسب عقد التأسيس",
    "Category:Television series endings by year": "تصنيف:مسلسلات تلفزيونية حسب سنة انتهاء العرض",
    "Category:Tetrapods by century of formal description": "تصنيف:رباعيات الأطراف حسب قرن الوصف",
    "Category:Vertebrates described in the 20th century": "تصنيف:فقاريات وصفت في القرن 20",
    "Category:Years in north korean television": "تصنيف:سنوات في التلفزة الكورية الشمالية",
    "Category:Years in the United States by state": "تصنيف:سنوات في الولايات المتحدة حسب الولاية",
    "Category:multi-sport events at Yemen": "تصنيف:أحداث رياضية متعددة في اليمن",
}
TEMPORAL_CASES = [
    ("temporal_1", temporal_1),
    ("temporal_2", temporal_2),
    ("temporal_3", temporal_3),
    ("temporal_4", temporal_4),
]


@pytest.mark.parametrize("name,data", TEMPORAL_CASES)
@pytest.mark.dump
def test_temporal(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"


@pytest.mark.parametrize("category, expected", temporal_1.items(), ids=temporal_1.keys())
@pytest.mark.fast
def test_temporal_1(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", temporal_2.items(), ids=temporal_2.keys())
@pytest.mark.fast
def test_temporal_2(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", temporal_3.items(), ids=temporal_3.keys())
@pytest.mark.fast
def test_temporal_3(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", temporal_4.items(), ids=temporal_4.keys())
@pytest.mark.fast
def test_temporal_4(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected



"""
# TODO: ADD SOME DATA FROM D:/categories_bot/langlinks/z2_data/NAT.json"""

NAT_PARAMS = ["{males}"]

NAT_DATA_to_check = {
    "{en_nat} singers": "مغنون ومغنيات {males}",  # 84
    "{en_nat} actors": "ممثلون وممثلات {males}",  # 90
    "{en_nat} boxers": "ملاكمون وملاكمات {males}",  # 136
    "{en_nat} cyclists": "دراجون ودراجات {males}",  # 68
    "{en_nat} film actors": "ممثلو وممثلات أفلام {males}",  # 74
    "{en_nat} television actors": "ممثلو وممثلات تلفاز {males}",  # 60
    "{en_nat} actors by medium": "ممثلون وممثلات {males} حسب الوسط",  # 65
    "{en_nat} footballers": "لاعبو ولاعبات كرة قدم {males}",  # 171
    "{en_nat} tennis players": "لاعبو ولاعبات كرة مضرب {males}",  # 87
    "{en_nat} basketball players": "لاعبو ولاعبات كرة سلة {males}",  # 65
    "{en_nat} expatriate footballers": "لاعبو ولاعبات كرة قدم {males} مغتربون",  # 162
    "{en_nat} businesspeople": "أصحاب أعمال {males}",  # 110
    "{en_nat} non-fiction writers": "كتاب غير روائيين {males}",  # 118
    "{en_nat} christians": "مسيحيون {males}",  # 134
    "{en_nat} muslims": "مسلمون {males}",  # 132
    "{en_nat} sports coaches": "مدربون رياضيون {males}",  # 110
    # "{en_nat} diaspora in united states": "أمريكيون {males}",  # 126
    "{en_nat} diaspora in united states": "شتات {males} في الولايات المتحدة",  # 126
}

NAT_DATA_MALES = {
    # 17th-century Hindu philosophers and theologians
    "{en_nat} philosophers and theologians": "فلاسفة ولاهوتيون {males}",
    "{en_nat} men's basketball players": "لاعبو كرة سلة {males}",  # 64
    "{en_nat} men's footballers": "لاعبو كرة قدم {males}",  # 167
    "{en_nat} expatriate men's footballers": "لاعبو كرة قدم {males} مغتربون",  # 163
    # "{en_nat} general election": "الانتخابات التشريعية {males}",
    # "{en_nat} presidential election": "الانتخابات الرئاسية {males}",
    # "{en_nat} sports coaches": "مدربو رياضة {males}",  # 110
    "{en_nat}": "{males}",  # 187
    # "{en_nat} people": "أعلام {males}",  # 187
    "{en_nat} lgbtq people": "أعلام إل جي بي تي كيو {males}",  # 187
    "{en_nat} people by occupation": "{males} حسب المهنة",  # 182
    "{en_nat} sports-people": "رياضيون {males}",  # 174
    "{en_nat} men": "رجال {males}",  # 183
    "{en_nat} sportsmen": "رياضيون رجال {males}",  # 182
    "{en_nat} people in sports": "{males} في ألعاب رياضية",  # 177
    "{en_nat} people by ethnic or national origin": "{males} حسب الأصل العرقي أو الوطني",  # 178
    "{en_nat} expatriates": "{males} مغتربون",  # 116
    "{en_nat} expatriate": "{males} مغتربون",  # 116
    "{en_nat} men by occupation": "رجال {males} حسب المهنة",  # 174
    "{en_nat} people by descent": "{males} حسب الأصل العرقي أو الوطني",  # 175
    "{en_nat} writers": "كتاب {males}",  # 95
    "{en_nat} politicians": "سياسيون {males}",  # 179
    "{en_nat} sports-people by sport": "رياضيون {males} حسب الرياضة",  # 178
    "{en_nat} expatriate sports-people": "رياضيون {males} مغتربون",  # 171
    "{en_nat} musicians": "موسيقيون {males}",  # 157
    "{en_nat} people by religion": "{males} حسب الدين",  # 164
    "{en_nat} expatriate sports-people by country of residence": "رياضيون {males} مغتربون حسب بلد الإقامة",  # 168
    "{en_nat} diplomats": "دبلوماسيون {males}",  # 172
    "{en_nat} emigrants": "{males} مهاجرون",  # 135
    "{en_nat} people by century": "{males} حسب القرن",  # 121
    "{en_nat} people by political orientation": "{males} حسب التوجه السياسي",  # 156
    "{en_nat} political people": "ساسة {males}",  # 160
    "{en_nat} military personnel": "عسكريون {males}",  # 106
    "{en_nat} activists": "ناشطون {males}",  # 159
    "{en_nat} lawyers": "محامون {males}",  # 158
    "{en_nat} athletes": "لاعبو قوى {males}",  # 79
    "{en_nat} football managers": "مدربو كرة قدم {males}",  # 154
    "{en_nat} martial artists": "ممارسو وممارسات فنون قتالية {males}",  # 120
    "{en_nat} prisoners and detainees": "سجناء ومعتقلون {males}",  # 153
    "{en_nat} scientists": "علماء {males}",  # 151
    "{en_nat} artists": "فنانون {males}",  # 129
    "{en_nat} swimmers": "سباحون {males}",  # 112
    "{en_nat} journalists": "صحفيون {males}",  # 138
    "{en_nat} runners": "عداؤون {males}",  # 142
    "{en_nat} poets": "شعراء {males}",  # 86
    "{en_nat} people by occupation and century": "{males} حسب المهنة والقرن",  # 130
    "{en_nat} film directors": "مخرجو أفلام {males}",  # 134
    "{en_nat} educators": "معلمون {males}",  # 80
    "{en_nat} competitors by sports event": "منافسون {males} حسب الحدث الرياضي",  # 136
    "{en_nat} academics": "أكاديميون {males}",  # 136
    "{en_nat} novelists": "روائيون {males}",  # 101
    "{en_nat} sprinters": "عداؤون سريعون {males}",  # 85
    "{en_nat} criminals": "مجرمون {males}",  # 124
    "{en_nat} murder victims": "ضحايا قتل {males}",  # 128
    "{en_nat} roman catholics": "رومان كاثوليك {males}",  # 127
    "{en_nat} religious leaders": "قادة دينيون {males}",  # 110
    "{en_nat} socialists": "اشتراكيون {males}",  # 127
    "{en_nat} judges": "قضاة {males}",  # 125
    "{en_nat} victims of crime": "ضحايا جرائم {males}",  # 123
    "{en_nat} economists": "اقتصاديون {males}",  # 124
    "{en_nat} mass media people": "إعلاميون {males}",  # 122
    "{en_nat} people by century and occupation": "{males} حسب القرن والمهنة",  # 105
    "{en_nat} writers by century": "كتاب {males} حسب القرن",  # 122
    "{en_nat} freestyle swimmers": "سباحو تزلج حر {males}",  # 122
    "{en_nat} politicians by century": "سياسيون {males} حسب القرن",  # 121
    "{en_nat} human rights activists": "{males} ناشطون في حقوق الإنسان",  # 108
    "{en_nat} composers": "ملحنون {males}",  # 102
    "{en_nat} physicians": "أطباء {males}",  # 117
    "{en_nat} feminists": "نسويون {males}",  # 115
    "{en_nat} historians": "مؤرخون {males}",  # 114
    "{en_nat} communists": "شيوعيون {males}",  # 113
    "{en_nat} people of german descent": "{males} من أصل ألماني",  # 109
    "executed {en_nat} people": "{males} أعدموا",  # 67
    "{en_nat} models": "عارضو أزياء {males}",  # 70
    "{en_nat} painters": "رسامون {males}",  # 94
    "{en_nat} bankers": "مصرفيون {males}",  # 109
    "{en_nat} people with disabilities": "{males} بإعاقات",  # 71
    "assassinated {en_nat} people": "{males} مغتالون",  # 109
    "{en_nat} jews": "يهود {males}",  # 103
    "{en_nat} theatre people": "مسرحيون {males}",  # 102
    "{en_nat} anti-communists": "{males} مناهضون للشيوعية",  # 87
    "{en_nat} prisoners sentenced to death": "مسجونون {males} حكم عليهم بالإعدام",  # 99
    "{en_nat} designers": "مصممون {males}",  # 106
    "{en_nat} engineers": "مهندسون {males}",  # 106
    "{en_nat} short story writers": "كتاب قصة قصيرة {males}",  # 71
    "{en_nat} actors by century": "ممثلون {males} حسب القرن",  # 69
    "{en_nat} murderers": "قتلة {males}",  # 103
    "{en_nat} producers": "منتجون {males}",  # 103
    "{en_nat} musicians by instrument": "موسيقيون {males} حسب الآلة",  # 97
    "{en_nat} architects": "معماريون {males}",  # 102
    "{en_nat} generals": "جنرالات {males}",  # 99
    "{en_nat} long-distance runners": "عداؤو مسافات طويلة {males}",  # 64
    "{en_nat} middle-distance runners": "عداؤو مسافات متوسطة {males}",  # 65
    "{en_nat} civil servants": "موظفو خدمة مدنية {males}",  # 100
    "{en_nat} nationalists": "قوميون {males}",  # 99
    # males with ذكور
    "{en_nat} male swimmers": "سباحون ذكور {males}",  # 101
    "{en_nat} male freestyle swimmers": "سباحو تزلج حر ذكور {males}",  # 121
    "{en_nat} male sprinters": "عداؤون سريعون ذكور {males}",  # 71
    # males without ذكور
    "{en_nat} male martial artists": "ممارسو فنون قتالية ذكور {males}",  # 137
    "{en_nat} male boxers": "ملاكمون ذكور {males}",  # 136
    "{en_nat} male athletes": "لاعبو قوى ذكور {males}",  # 81
    "{en_nat} male actors": "ممثلون ذكور {males}",  # 91
    "{en_nat} male singers": "مغنون ذكور {males}",  # 85
    "{en_nat} male writers": "كتاب ذكور {males}",  # 86
    "{en_nat} male film actors": "ممثلو أفلام ذكور {males}",  # 80
}



#!/usr/bin/python3
"""
!
"""

import functools
import json
from pathlib import Path
from typing import Any, Dict, List

Dir2 = Path(__file__).parent.parent.parent


def _build_json_path(relative_path: str) -> Path:
    """Return the full path to a JSON file under ``jsons``.

    The helper accepts either bare filenames (``"example"``) or paths that
    include nested folders (``"geography/us_counties"``). When the provided
    path does not include an extension, ``.json`` is appended automatically.
    """
    path = Path(relative_path)
    if path.suffix != ".json":
        path = path.with_suffix(".json")
    return Dir2 / "jsons" / path


@functools.lru_cache(maxsize=128)
def open_json_file(file_path: str = "") -> Dict[str, Any] | List[Any]:
    """Open a JSON resource from the bundled ``jsons`` directory by name.

    Results are cached to avoid repeated file I/O for the same file.
    """
    if not file_path:
        return {}
    file_path_path = _build_json_path(file_path)
    if not file_path_path.exists():
        print(f"file {file_path_path} not found")
        return {}
    try:
        with open(file_path_path, "r", encoding="utf-8") as f:
            return json.load(f)
    except BaseException:
        print(f"cant open {file_path_path.name}")
    return {}


def open_json(file_path: str = "") -> dict[str, Any] | list[Any]:
    """Open a JSON file given a relative path under the ``jsons`` directory."""
    return open_json_file(file_path)



"""
Tests
"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.jobs_multi_sports_reslover import jobs_in_multi_sports

multi_sports_data_competitors = {
    "summer olympics coaches": "مدربون في الألعاب الأولمبية الصيفية",
    "paralympic coaches": "مدربون في الألعاب البارالمبية",
    "afc asian cup managers": "مدربون في كأس آسيا",
    "olympic gold medalists": "فائزون بميداليات ذهبية أولمبية",
    "paralympic competitors": "منافسون بارالمبيون",
    "african games competitors": "منافسون في الألعاب الإفريقية",
    "asian games competitors": "منافسون في الألعاب الآسيوية",
    "parapan american games competitors": "منافسون في ألعاب بارابان الأمريكية",
    "sea games competitors": "منافسون في ألعاب البحر",
    "south american games competitors": "منافسون في ألعاب أمريكا الجنوبية",
    "summer olympics competitors": "منافسون أولمبيون صيفيون",
    "summer world university games competitors": "منافسون في ألعاب الجامعات العالمية الصيفية",
    "winter olympics competitors": "منافسون أولمبيون شتويون",
    "pan american games competitors": "منافسون في دورة الألعاب الأمريكية",
    "maccabiah games competitors": "منافسون في الألعاب المكابيه",
    "mediterranean games competitors": "منافسون في الألعاب المتوسطية",
    "islamic solidarity games competitors": "منافسون في ألعاب التضامن الإسلامي",
    "european games competitors": "منافسون في الألعاب الأوروبية",
    "asian para games competitors": "منافسون في الألعاب البارالمبية الآسيوية",
    "central american and caribbean games competitors": "منافسون في ألعاب أمريكا الوسطى والكاريبي",
    "commonwealth games competitors": "منافسون في ألعاب الكومنولث",
}

multi_sports_data = {
    "paralympic sailors": "بحارة في الألعاب البارالمبية",
    "pan american games sailors": "بحارة في دورة الألعاب الأمريكية",
    "islamic solidarity games cyclists": "دراجون في ألعاب التضامن الإسلامي",
    "paralympic cyclists": "دراجون في الألعاب البارالمبية",
    "pan american games cyclists": "دراجون في دورة الألعاب الأمريكية",
    "islamic solidarity games weightlifters": "رباعون في ألعاب التضامن الإسلامي",
    "commonwealth games weightlifters": "رباعون في ألعاب الكومنولث",
    "asian games weightlifters": "رباعون في الألعاب الآسيوية",
    "paralympic weightlifters": "رباعون في الألعاب البارالمبية",
    "pan american games weightlifters": "رباعون في دورة الألعاب الأمريكية",
    "islamic solidarity games shooters": "رماة في ألعاب التضامن الإسلامي",
    "asian games shooters": "رماة في الألعاب الآسيوية",
    "paralympic shooters": "رماة في الألعاب البارالمبية",
    "islamic solidarity games track and field athletes": "رياضيو المسار والميدان في ألعاب التضامن الإسلامي",
    "paralympic track and field athletes": "رياضيو المسار والميدان في الألعاب البارالمبية",
    "pan american games track and field athletes": "رياضيو المسار والميدان في دورة الألعاب الأمريكية",
    "islamic solidarity games swimmers": "سباحون في ألعاب التضامن الإسلامي",
    "commonwealth games swimmers": "سباحون في ألعاب الكومنولث",
    "asian games swimmers": "سباحون في الألعاب الآسيوية",
    "paralympic swimmers": "سباحون في الألعاب البارالمبية",
    "pan american games swimmers": "سباحون في دورة الألعاب الأمريكية",
    "paralympic marathon runners": "عداؤو ماراثون في الألعاب البارالمبية",
    "commonwealth games divers": "غواصون في ألعاب الكومنولث",
    "asian games divers": "غواصون في الألعاب الآسيوية",
    "paralympic equestrians": "فرسان خيول في الألعاب البارالمبية",
    "pan american games equestrians": "فرسان خيول في دورة الألعاب الأمريكية",
    "maccabiah games rugby union players": "لاعبو اتحاد رجبي في الألعاب المكابيه",
    "commonwealth games squash players": "لاعبو اسكواش في ألعاب الكومنولث",
    "paralympic boccia players": "لاعبو بوتشيا في الألعاب البارالمبية",
    "commonwealth games bowls players": "لاعبو بولينج في ألعاب الكومنولث",
    "asian games bowlers": "لاعبو بولينج في الألعاب الآسيوية",
    "pan american games bowlers": "لاعبو بولينج في دورة الألعاب الأمريكية",
    "youth olympics biathletes": "لاعبو بياثلون في الألعاب الأولمبية الشبابية",
    "paralympic biathletes": "لاعبو بياثلون في الألعاب البارالمبية",
    "islamic solidarity games taekwondo practitioners": "لاعبو تايكوندو في ألعاب التضامن الإسلامي",
    "asian games taekwondo practitioners": "لاعبو تايكوندو في الألعاب الآسيوية",
    "african games taekwondo practitioners": "لاعبو تايكوندو في الألعاب الإفريقية",
    "paralympic taekwondo practitioners": "لاعبو تايكوندو في الألعاب البارالمبية",
    "commonwealth games triathletes": "لاعبو ترياثلون في ألعاب الكومنولث",
    "commonwealth games badminton players": "لاعبو تنس ريشة في ألعاب الكومنولث",
    "parapan american games badminton players": "لاعبو تنس ريشة في ألعاب بارابان الأمريكية",
    "asian games badminton players": "لاعبو تنس ريشة في الألعاب الآسيوية",
    "paralympic badminton players": "لاعبو تنس ريشة في الألعاب البارالمبية",
    "islamic solidarity games gymnasts": "لاعبو جمباز في ألعاب التضامن الإسلامي",
    "commonwealth games gymnasts": "لاعبو جمباز في ألعاب الكومنولث",
    "european games gymnasts": "لاعبو جمباز في الألعاب الأوروبية",
    "maccabiah games gymnasts": "لاعبو جمباز في الألعاب المكابيه",
    "pan american games gymnasts": "لاعبو جمباز في دورة الألعاب الأمريكية",
    "islamic solidarity games judoka": "لاعبو جودو في ألعاب التضامن الإسلامي",
    "parapan american games judoka": "لاعبو جودو في ألعاب بارابان الأمريكية",
    "asian games judoka": "لاعبو جودو في الألعاب الآسيوية",
    "african games judoka": "لاعبو جودو في الألعاب الإفريقية",
    "paralympic judoka": "لاعبو جودو في الألعاب البارالمبية",
    "parapan american games wheelchair rugby players": "لاعبو رجبي على كراسي متحركة في ألعاب بارابان الأمريكية",
    "paralympic wheelchair rugby players": "لاعبو رجبي على كراسي متحركة في الألعاب البارالمبية",
    "commonwealth games rugby sevens players": "لاعبو سباعيات رجبي في ألعاب الكومنولث",
    "pan american games rugby sevens players": "لاعبو سباعيات رجبي في دورة الألعاب الأمريكية",
    "paralympic snooker players": "لاعبو سنوكر في الألعاب البارالمبية",
    "asian games xiangqi players": "لاعبو شطرنج صيني في الألعاب الآسيوية",
    "asian games chess players": "لاعبو شطرنج في الألعاب الآسيوية",
    "asian games golfers": "لاعبو غولف في الألعاب الآسيوية",
    "paralympic long jumpers": "لاعبو قفز طويل في الألعاب البارالمبية",
    "commonwealth games athletes": "لاعبو قوى في ألعاب الكومنولث",
    "asian games athletes": "لاعبو قوى في الألعاب الآسيوية",
    "paralympic athletes": "لاعبو قوى في الألعاب البارالمبية",
    "pan american games athletes": "لاعبو قوى في دورة الألعاب الأمريكية",
    "parapan american games wheelchair basketball players": "لاعبو كرة سلة على كراسي متحركة في ألعاب بارابان الأمريكية",
    "paralympic wheelchair basketball players": "لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية",
    "islamic solidarity games basketball players": "لاعبو كرة سلة في ألعاب التضامن الإسلامي",
    "pan american games basketball players": "لاعبو كرة سلة في دورة الألعاب الأمريكية",
    "islamic solidarity games volleyball players": "لاعبو كرة طائرة في ألعاب التضامن الإسلامي",
    "asian games volleyball players": "لاعبو كرة طائرة في الألعاب الآسيوية",
    "european games volleyball players": "لاعبو كرة طائرة في الألعاب الأوروبية",
    "paralympic volleyball players": "لاعبو كرة طائرة في الألعاب البارالمبية",
    "pan american games volleyball players": "لاعبو كرة طائرة في دورة الألعاب الأمريكية",
    "islamic solidarity games table tennis players": "لاعبو كرة طاولة في ألعاب التضامن الإسلامي",
    "asian games table tennis players": "لاعبو كرة طاولة في الألعاب الآسيوية",
    "paralympic table tennis players": "لاعبو كرة طاولة في الألعاب البارالمبية",
    "pan american games baseball players": "لاعبو كرة قاعدة في دورة الألعاب الأمريكية",
    "islamic solidarity games footballers": "لاعبو كرة قدم في ألعاب التضامن الإسلامي",
    "asian games footballers": "لاعبو كرة قدم في الألعاب الآسيوية",
    "paralympic footballers": "لاعبو كرة قدم في الألعاب البارالمبية",
    "pan american games footballers": "لاعبو كرة قدم في دورة الألعاب الأمريكية",
    "pan american games softball players": "لاعبو كرة لينة في دورة الألعاب الأمريكية",
    "asian games water polo players": "لاعبو كرة ماء في الألعاب الآسيوية",
    "pan american games water polo players": "لاعبو كرة ماء في دورة الألعاب الأمريكية",
    "parapan american games wheelchair tennis players": "لاعبو كرة مضرب على كراسي متحركة في ألعاب بارابان الأمريكية",
    "paralympic wheelchair tennis players": "لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية",
    "islamic solidarity games tennis players": "لاعبو كرة مضرب في ألعاب التضامن الإسلامي",
    "asian games tennis players": "لاعبو كرة مضرب في الألعاب الآسيوية",
    "pan american games tennis players": "لاعبو كرة مضرب في دورة الألعاب الأمريكية",
    "asian games soft tennis players": "لاعبو كرة مضرب لينة في الألعاب الآسيوية",
    "paralympic goalball players": "لاعبو كرة هدف في الألعاب البارالمبية",
    "islamic solidarity games handball players": "لاعبو كرة يد في ألعاب التضامن الإسلامي",
    "asian games handball players": "لاعبو كرة يد في الألعاب الآسيوية",
    "pan american games handball players": "لاعبو كرة يد في دورة الألعاب الأمريكية",
    "asian games cricketers": "لاعبو كريكت في الألعاب الآسيوية",
    "paralympic wheelchair curlers": "لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية",
    "youth olympics ice hockey players": "لاعبو هوكي جليد في الألعاب الأولمبية الشبابية",
    "paralympic sledge hockey players": "لاعبو هوكي مزلجة في الألعاب البارالمبية",
    "commonwealth games field hockey players": "لاعبو هوكي ميدان في ألعاب الكومنولث",
    "youth olympics field hockey players": "لاعبو هوكي ميدان في الألعاب الأولمبية الشبابية",
    "pan american games field hockey players": "لاعبو هوكي ميدان في دورة الألعاب الأمريكية",
    "paralympic triple jumpers": "لاعبو وثب ثلاثي في الألعاب البارالمبية",
    "afc asian cup players": "لاعبون في كأس آسيا",
    "paralympic wheelchair fencers": "مبارزون على الكراسي المتحركة في الألعاب البارالمبية",
    "islamic solidarity games fencers": "مبارزون في ألعاب التضامن الإسلامي",
    "commonwealth games fencers": "مبارزون في ألعاب الكومنولث",
    "youth olympics nordic combined skiers": "متزحلقو تزلج نوردي مزدوج في الألعاب الأولمبية الشبابية",
    "asian games alpine skiers": "متزحلقو منحدرات ثلجية في الألعاب الآسيوية",
    "paralympic alpine skiers": "متزحلقو منحدرات ثلجية في الألعاب البارالمبية",
    "paralympic cross-country skiers": "متزحلقون ريفيون في الألعاب البارالمبية",
    "paralympic snowboarders": "متزلجون على الثلج في الألعاب البارالمبية",
    "asian games ski-orienteers": "متسابقو تزلج موجه في الألعاب الآسيوية",
    "asian games modern pentathletes": "متسابقو خماسي حديث في الألعاب الآسيوية",
    "asian games canoeists": "متسابقو قوارب الكانوي في الألعاب الآسيوية",
    "paralympic wheelchair racers": "متسابقو كراسي متحركة في الألعاب البارالمبية",
    "asian games sport climbers": "متسلقون في الألعاب الآسيوية",
    "paralympic rowers": "مجدفون في الألعاب البارالمبية",
    "pan american games rowers": "مجدفون في دورة الألعاب الأمريكية",
    "paralympic wheelchair rugby coaches": "مدربو رجبي على كراسي متحركة في الألعاب البارالمبية",
    "paralympic wheelchair basketball coaches": "مدربو كرة سلة على كراسي متحركة في الألعاب البارالمبية",
    "islamic solidarity games wrestlers": "مصارعون في ألعاب التضامن الإسلامي",
    "asian games wrestlers": "مصارعون في الألعاب الآسيوية",
    "paralympic wrestlers": "مصارعون في الألعاب البارالمبية",
    "pan american games wrestlers": "مصارعون في دورة الألعاب الأمريكية",
    "islamic solidarity games kickboxers": "مقاتلو كيك بوكسنغ في ألعاب التضامن الإسلامي",
    "islamic solidarity games boxers": "ملاكمون في ألعاب التضامن الإسلامي",
    "commonwealth games boxers": "ملاكمون في ألعاب الكومنولث",
    "asian games boxers": "ملاكمون في الألعاب الآسيوية",
    "european games boxers": "ملاكمون في الألعاب الأوروبية",
    "pan american games boxers": "ملاكمون في دورة الألعاب الأمريكية",
    "paralympic powerlifters": "ممارسو رياضة القوة في الألعاب البارالمبية",
    "asian games sambo practitioners": "ممارسو سامبو في الألعاب الآسيوية",
    "european games sambo practitioners": "ممارسو سامبو في الألعاب الأوروبية",
    "islamic solidarity games karateka": "ممارسو كاراتيه في ألعاب التضامن الإسلامي",
    "asian games karateka": "ممارسو كاراتيه في الألعاب الآسيوية",
    "islamic solidarity games archers": "نبالون في ألعاب التضامن الإسلامي",
    "asian games archers": "نبالون في الألعاب الآسيوية",
    "paralympic archers": "نبالون في الألعاب البارالمبية",
    "pan american games archers": "نبالون في دورة الألعاب الأمريكية",
}


@pytest.mark.parametrize("category, expected", multi_sports_data.items(), ids=multi_sports_data.keys())
@pytest.mark.fast
def test_jobs_in_multi_sports(category: str, expected: str) -> None:
    label = jobs_in_multi_sports(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", multi_sports_data.items(), ids=multi_sports_data.keys())
# @pytest.mark.parametrize("category, expected", multi_sports_data_competitors.items(), ids=multi_sports_data_competitors.keys())
@pytest.mark.fast
def test_jobs_in_multi_sports_new(category: str, expected: str) -> None:
    label = jobs_in_multi_sports(category)
    assert label == expected


ENTERTAINMENT_CASES = [
    ("test_jobs_in_multi_sports", multi_sports_data, jobs_in_multi_sports),
]


@pytest.mark.parametrize("name,data,callback", ENTERTAINMENT_CASES)
@pytest.mark.dump
def test_entertainment(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""

English country-name → Arabic country-name.

"""
import functools

from ...helps import logger
from ...translations import SPORTS_KEYS_FOR_JOBS, countries_from_nat
from ...translations_formats import MultiDataFormatterBase, format_multi_data

# TODO: This all wrong arabic values need to be fixed later
under_data_to_check = {
    "{en} {en_sport} teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national amateur teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national junior mens teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national mens teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national womens teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national youth teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national youth womens teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national junior womens teams": "فرق {sport_jobs} {female}",
    "{en} {under_en} teams": "فرق {female} {under_ar}",
    "{en} {en_sport} {under_en} teams": "فرق {sport_jobs} {female} {under_ar}",
    "{en} {en_sport} national amateur {under_en} teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national junior mens {under_en} teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national junior womens {under_en} teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national mens {under_en} teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national {under_en} teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national womens {under_en} teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} national youth {under_en} teams": "فرق {sport_jobs} {female}",
    "{en} {en_sport} youth womens {under_en} teams": "فرق {sport_jobs} {female} {under_ar} للشابات",
    # ["softball national youth womens under-24 teams"] = "منتخبات كرة لينة تحت 24 سنة للشابات"
    "{en} {en_sport} national youth womens {under_en} teams": "منتخبات {sport_jobs} {under_ar} للشابات",
}

under_data = {
    "under-13": "تحت 13 سنة",
    "under-14": "تحت 14 سنة",
    "under-15": "تحت 15 سنة",
    "under-16": "تحت 16 سنة",
    "under-17": "تحت 17 سنة",
    "under-18": "تحت 18 سنة",
    "under-19": "تحت 19 سنة",
    "under-20": "تحت 20 سنة",
    "under-21": "تحت 21 سنة",
    "under-23": "تحت 23 سنة",
    "under-24": "تحت 24 سنة",
    "u23": "تحت 23 سنة",
}

# TODO: support nats keys
sports_data_under = {
    "{en_sport} national youth womens {under_en} teams": "منتخبات {sport_jobs} {under_ar} للشابات",
    "national mens {under_en} {en_sport} teams": "منتخبات {sport_jobs} {under_ar} للرجال",
    "mens {under_en} national {en_sport} teams": "منتخبات {sport_jobs} {under_ar} للرجال",
    # [multi-national womens under-19 football teams] = "منتخبات كرة قدم تحت 19 سنة متعددة الجنسيات للسيدات"
    "multi-national womens {under_en} {en_sport} teams": "منتخبات {sport_jobs} {under_ar} متعددة الجنسيات للسيدات",
    "national amateur {under_en} {en_sport} teams": "منتخبات {sport_jobs} {under_ar} للهواة",
    "national junior mens {under_en} {en_sport} teams": "منتخبات {sport_jobs} {under_ar} للناشئين",
    "national junior womens {under_en} {en_sport} teams": "منتخبات {sport_jobs} {under_ar} للناشئات",
    "national womens {under_en} {en_sport} teams": "منتخبات {sport_jobs} {under_ar} للسيدات",
    "national youth womens {under_en} {en_sport} teams": "منتخبات {sport_jobs} {under_ar} للشابات",
    "national youth {under_en} {en_sport} teams": "منتخبات {sport_jobs} {under_ar} للشباب",
    "national {under_en} {en_sport} teams": "منتخبات {sport_jobs} {under_ar}",
}

main_data_under = {
    "{en} {under_en} international players": "لاعبون {under_ar} دوليون من {ar}",
    "{en} {under_en} international playerss": "لاعبون {under_ar} دوليون من {ar}",
    "{en} amateur {under_en} international footballers": "لاعبو منتخب {ar} {under_ar} لكرة القدم للهواة",
    "{en} amateur {under_en} international soccer players": "لاعبو منتخب {ar} {under_ar} لكرة القدم للهواة",
    "{en} amateur {under_en} international soccer playerss": "لاعبو منتخب {ar} {under_ar} لكرة القدم للهواة",
    "{en} mens a {under_en} international footballers": "لاعبو منتخب {ar} {under_ar} لكرة القدم للرجال للمحليين",
    "{en} mens a {under_en} international soccer players": "لاعبو منتخب {ar} {under_ar} لكرة القدم للرجال للمحليين",
    "{en} mens a {under_en} international soccer playerss": "لاعبو منتخب {ar} {under_ar} لكرة القدم للرجال للمحليين",
    "{en} mens b {under_en} international footballers": "لاعبو منتخب {ar} {under_ar} لكرة القدم الرديف للرجال",
    "{en} mens b {under_en} international soccer players": "لاعبو منتخب {ar} {under_ar} لكرة القدم الرديف للرجال",
    "{en} mens b {under_en} international soccer playerss": "لاعبو منتخب {ar} {under_ar} لكرة القدم الرديف للرجال",
    "{en} mens youth {under_en} international footballers": "لاعبو منتخب {ar} {under_ar} لكرة القدم للشباب",
    "{en} mens youth {under_en} international soccer players": "لاعبو منتخب {ar} {under_ar} لكرة القدم للشباب",
    "{en} mens youth {under_en} international soccer playerss": "لاعبو منتخب {ar} {under_ar} لكرة القدم للشباب",
    "{en} mens {under_en} international footballers": "لاعبو منتخب {ar} {under_ar} لكرة القدم للرجال",
    "{en} mens {under_en} international soccer players": "لاعبو منتخب {ar} {under_ar} لكرة القدم للرجال",
    "{en} mens {under_en} international soccer playerss": "لاعبو منتخب {ar} {under_ar} لكرة القدم للرجال",
    "{en} womens youth {under_en} international footballers": "لاعبات منتخب {ar} {under_ar} لكرة القدم للشابات",
    "{en} womens youth {under_en} international soccer players": "لاعبات منتخب {ar} {under_ar} لكرة القدم للشابات",
    "{en} womens youth {under_en} international soccer playerss": "لاعبات منتخب {ar} {under_ar} لكرة القدم للشابات",
    "{en} womens {under_en} international footballers": "لاعبات منتخب {ar} {under_ar} لكرة القدم للسيدات",
    "{en} womens {under_en} international soccer players": "لاعبات منتخب {ar} {under_ar} لكرة القدم للسيدات",
    "{en} womens {under_en} international soccer playerss": "لاعبات منتخب {ar} {under_ar} لكرة القدم للسيدات",
    "{en} youth {under_en} international footballers": "لاعبو منتخب {ar} {under_ar} لكرة القدم للشباب",
    "{en} youth {under_en} international soccer players": "لاعبو منتخب {ar} {under_ar} لكرة القدم للشباب",
    "{en} youth {under_en} international soccer playerss": "لاعبو منتخب {ar} {under_ar} لكرة القدم للشباب",
    "{en} {under_en} international footballers": "لاعبو منتخب {ar} {under_ar} لكرة القدم",
    "{en} {under_en} international managers": "مدربون {under_ar} دوليون من {ar}",
    "{en} {under_en} international soccer players": "لاعبو منتخب {ar} {under_ar} لكرة القدم",
    "{en} {under_en} international soccer playerss": "لاعبو منتخب {ar} {under_ar} لكرة القدم ",
}


@functools.lru_cache(maxsize=1)
def _load_bot_with_sports_keys() -> MultiDataFormatterBase:
    return format_multi_data(
        formatted_data=sports_data_under,
        data_list=under_data,
        key_placeholder="{under_en}",
        value_placeholder="{under_ar}",
        data_list2=SPORTS_KEYS_FOR_JOBS,
        key2_placeholder="{en_sport}",
        value2_placeholder="{sport_jobs}",
    )


@functools.lru_cache(maxsize=1)
def _load_under_bot() -> MultiDataFormatterBase:
    return format_multi_data(
        formatted_data=main_data_under,
        data_list=under_data,
        key_placeholder="{under_en}",
        value_placeholder="{under_ar}",
        data_list2=countries_from_nat,
        key2_placeholder="{en}",
        value2_placeholder="{ar}",
    )


@functools.lru_cache(maxsize=10000)
def fix_keys(category: str) -> str:
    category = category.replace("'", "").lower().replace("category:", "")

    replacements = {}

    for old, new in replacements.items():
        category = category.replace(old, new)

    return category.strip()


@functools.lru_cache(maxsize=1000)
def resolve_sport_under_labels(category: str) -> str:
    category = fix_keys(category)
    logger.debug(f"<<yellow>> start resolve_sport_under_labels: {category=}")

    result = _load_under_bot().search(category) or _load_bot_with_sports_keys().search(category) or ""

    logger.info_if_or_debug(f"<<yellow>> end resolve_sport_under_labels: {category=}, {result=}", result)
    return result


__all__ = [
    "resolve_sport_under_labels",
]



#
import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data_empty = {
    "lists of 20th millennium women's olympic table tennis players films by city": "قوائم أفلام لاعبات كرة طاولة أولمبيات الألفية 20 حسب المدينة",
    "category:2020 women's wheelchair tennis players by city": "تصنيف:لاعبات كرة مضرب على كراسي متحركة نسائية في 2020 حسب المدينة",
    "Category:2020 wheelchair tennis by city": "تصنيف:كرة المضرب على الكراسي المتحركة في 2020 حسب المدينة",
    "Category:Political positions of the 2000 United States presidential candidates": "تصنيف:مواقف سياسية لمرشحي الرئاسة الأمريكية 2000",
    "Category:Political positions of the 2008 United States presidential candidates": "تصنيف:مواقف سياسية لمرشحي الرئاسة الأمريكية 2008",
    "Category:Political positions of the 2016 United States presidential candidates": "تصنيف:مواقف سياسية لمرشحي الرئاسة الأمريكية 2016",
    "Category:Political positions of the 2020 United States presidential candidates": "تصنيف:مواقف سياسية لمرشحي الرئاسة الأمريكية 2020",
    "Category:Political positions of the 2024 United States presidential candidates": "تصنيف:مواقف سياسية لمرشحي الرئاسة الأمريكية 2024",
    "Category:17th-century dukes of Limburg": "تصنيف:دوقات ليمبورغ في القرن 17",
    "Category:Politics and technology": "تصنيف:السياسة والتقانة",
    "Category:National association football second-tier league champions": "x",
    "Category:Association football third-tier league seasons": "x",
    "Category:Association football second-tier league seasons": "x",
    "Category:Association football fourth-tier league seasons": "x",
    "Category:National association football third-tier leagues": "x",
    "Category:National association football fifth-tier leagues": "x",
    "Category:National association football fourth-tier leagues": "x",
    "Category:National association football second-tier leagues": "x",
    "Category:National association football seventh-tier leagues": "x",
    "Category:National association football sixth-tier leagues": "x",
    "Category:Seasons in European third-tier association football leagues": "x",
    "Category:Academic staff of Incheon National University": "تصنيف:أعضاء هيئة تدريس جامعة إنتشون الوطنية",
    "Category:Lists of 1900s films": "تصنيف:قوائم أفلام إنتاج عقد 1900",
    "Category:Academic staff of University of Galați": "تصنيف:أعضاء هيئة تدريس جامعة غالاتس",
    "Category:Women members of Senate of Spain": "تصنيف:عضوات مجلس شيوخ إسبانيا",
    "Category:Defunct shopping malls in Malaysia": "تصنيف:مراكز تسوق سابقة في ماليزيا",
    "Category:Defunct communist parties in Nepal": "تصنيف:أحزاب شيوعية سابقة في نيبال",
    "Category:Defunct European restaurants in London": "تصنيف:مطاعم أوروبية سابقة في لندن",
    "Category:Burial sites of Aragonese royal houses": "",
    "Category:Burial sites of Castilian royal houses": "",
    "Category:Burial sites of Frankish noble families": "",
    "Category:Burial sites of Georgian royal dynasties": "",
    "Category:Burial sites of Hawaiian royal houses": "",
    "Category:Burial sites of Hessian noble families": "",
    "Category:Burial sites of Kotromanić dynasty": "",
    "Category:Burial sites of Leonese royal houses": "",
    "Category:Burial sites of Lorraine noble families": "",
    "Category:Burial sites of Lower Saxon noble families": "",
    "Category:Burial sites of Muslim dynasties": "",
    "Category:Burial sites of Navarrese royal houses": "",
    "Category:Burial sites of Neapolitan royal houses": "",
    "Category:Burial sites of noble families": "",
    "Category:Burial sites of Norman families": "",
}

data0 = {
    "Category:chess composers": "تصنيف:مؤلفو مسائل شطرنج",
    "Category:cultural depictions of Canadian activists": "تصنيف:تصوير ثقافي عن ناشطون كنديون",
    "Category:Assassinated Canadian activists": "تصنيف:ناشطون كنديون مغتالون",
    "Category:Assassinated Guatemalan diplomats": "تصنيف:دبلوماسيون غواتيماليون مغتالون",
    "Category:Assassinated Swedish diplomats": "تصنيف:دبلوماسيون سويديون مغتالون",
    "Category:Ancient Indian people by occupation": "تصنيف:هنود قدماء حسب المهنة",
    "Category:Fictional Australian criminals": "تصنيف:مجرمون أستراليون خياليون",
    "Category:Assassinated Peruvian politicians": "تصنيف:سياسيون بيرويون مغتالون",
    # "Category:Native American women leaders": "تصنيف:قائدات أمريكيات أصليون",
    "yemeni national junior women's under-16 football teams players": "تصنيف:لاعبات منتخبات كرة قدم وطنية يمنية تحت 16 سنة للناشئات",
    "yemeni national junior women's football teams players": "تصنيف:لاعبات منتخبات كرة قدم وطنية يمنية للناشئات",
    "yemeni national women's under-16 football teams players": "تصنيف:لاعبات منتخبات كرة قدم وطنية يمنية تحت 16 سنة للسيدات",
    "yemeni national youth women's under-16 football teams players": "تصنيف:لاعبات منتخبات كرة قدم وطنية يمنية تحت 16 سنة للشابات",
    "yemeni national youth women's football teams players": "تصنيف:لاعبات منتخبات كرة قدم وطنية يمنية للشابات",
    "Category:zaïrean wheelchair sports federation": "تصنيف:الاتحاد الزائيري للرياضة على الكراسي المتحركة",
    "Category:surinamese sports federation": "تصنيف:الاتحاد السورينامي للرياضة",
    "Category:Romania football manager history navigational boxes": "تصنيف:صناديق تصفح تاريخ مدربو كرة قدم رومانيا",
    "Category:Jewish football clubs": "تصنيف:أندية كرة القدم اليهودية",
    "Category:Jewish sports": "تصنيف:ألعاب رياضية يهودية",
    "Category:European League of Football coaches": "تصنيف:مدربو الدوري الأوروبي لكرة القدم",
    "Category:Australian soccer by year": "تصنيف:كرة القدم الأسترالية حسب السنة",
    "Category:Political positions of United States presidential candidates": "تصنيف:مواقف سياسية لمرشحي الرئاسة الأمريكية",
}

data1 = {
    "Category:Lists of American reality television series episodes": "تصنيف:قوائم حلقات مسلسلات تلفزيونية واقعية أمريكية",
    "Category:Academic staff of University of Nigeria": "تصنيف:أعضاء هيئة تدريس جامعة نيجيريا",
    "Category:Early modern history of Portugal": "تصنيف:تاريخ البرتغال الحديث المبكر",
    "south american second tier football leagues": "تصنيف:دوريات كرة قدم أمريكية جنوبية من الدرجة الثانية",
    "european second tier basketball leagues": "تصنيف:دوريات كرة سلة أوروبية من الدرجة الثانية",
    "european second tier ice hockey leagues": "تصنيف:دوريات هوكي جليد أوروبية من الدرجة الثانية",
    "israeli basketball premier league": "تصنيف:الدوري الإسرائيلي الممتاز لكرة السلة",
    "Category:Burial sites of ancient Irish dynasties": "تصنيف:مواقع دفن أسر أيرلندية قديمة",
    "Category:Burial sites of Arab dynasties": "تصنيف:مواقع دفن أسر عربية",
    "Category:Burial sites of Asian royal families": "تصنيف:مواقع دفن عائلات ملكية آسيوية",
    "Category:Burial sites of Austrian noble families": "تصنيف:مواقع دفن عائلات نبيلة نمساوية",
    "Category:Burial sites of Belgian noble families": "تصنيف:مواقع دفن عائلات نبيلة بلجيكية",
    "Category:Burial sites of Bohemian royal houses": "تصنيف:مواقع دفن بيوت ملكية بوهيمية",
    "Category:Burial sites of Bosnian noble families": "تصنيف:مواقع دفن عائلات نبيلة بوسنية",
    "Category:Burial sites of British royal houses": "تصنيف:مواقع دفن بيوت ملكية بريطانية",
    "Category:Burial sites of Bulgarian royal houses": "تصنيف:مواقع دفن بيوت ملكية بلغارية",
    "Category:Burial sites of Byzantine imperial dynasties": "تصنيف:مواقع دفن أسر إمبراطورية بيزنطية",
    "Category:Burial sites of Cornish families": "تصنيف:مواقع دفن عائلات كورنية",
    "Category:Burial sites of Danish noble families": "تصنيف:مواقع دفن عائلات نبيلة دنماركية",
    "Category:Burial sites of Dutch noble families": "تصنيف:مواقع دفن عائلات نبيلة هولندية",
    "Category:Burial sites of English families": "تصنيف:مواقع دفن عائلات إنجليزية",
    "Category:Burial sites of English royal houses": "تصنيف:مواقع دفن بيوت ملكية إنجليزية",
    "Category:Burial sites of European noble families": "تصنيف:مواقع دفن عائلات نبيلة أوروبية",
    "Category:Burial sites of European royal families": "تصنيف:مواقع دفن عائلات ملكية أوروبية",
    "Category:Burial sites of French noble families": "تصنيف:مواقع دفن عائلات نبيلة فرنسية",
    "Category:Burial sites of French royal families": "تصنيف:مواقع دفن عائلات ملكية فرنسية",
    "Category:Burial sites of German noble families": "تصنيف:مواقع دفن عائلات نبيلة ألمانية",
    "Category:Burial sites of German royal houses": "تصنيف:مواقع دفن بيوت ملكية ألمانية",
    "Category:Burial sites of Hungarian noble families": "تصنيف:مواقع دفن عائلات نبيلة مجرية",
    "Category:Burial sites of Hungarian royal houses": "تصنيف:مواقع دفن بيوت ملكية مجرية",
    "Category:Burial sites of Iranian dynasties": "تصنيف:مواقع دفن أسر إيرانية",
    "Category:Burial sites of Irish noble families": "تصنيف:مواقع دفن عائلات نبيلة أيرلندية",
    "Category:Burial sites of Irish royal families": "تصنيف:مواقع دفن عائلات ملكية أيرلندية",
    "Category:Burial sites of Italian noble families": "تصنيف:مواقع دفن عائلات نبيلة إيطالية",
    "Category:Burial sites of Italian royal houses": "تصنيف:مواقع دفن بيوت ملكية إيطالية",
    "Category:Burial sites of Lithuanian noble families": "تصنيف:مواقع دفن عائلات نبيلة ليتوانية",
    "Category:Burial sites of Luxembourgian noble families": "تصنيف:مواقع دفن عائلات نبيلة لوكسمبورغية",
    "Category:Burial sites of Mexican noble families": "تصنيف:مواقع دفن عائلات نبيلة مكسيكية",
    "Category:Burial sites of Middle Eastern royal families": "تصنيف:مواقع دفن عائلات ملكية شرقية أوسطية",
    "Category:Burial sites of Polish noble families": "تصنيف:مواقع دفن عائلات نبيلة بولندية",
    "Category:Burial sites of Polish royal houses": "تصنيف:مواقع دفن بيوت ملكية بولندية",
    "Category:Burial sites of Romanian noble families": "تصنيف:مواقع دفن عائلات نبيلة رومانية",
    "Category:Burial sites of Romanian royal houses": "تصنيف:مواقع دفن بيوت ملكية رومانية",
    "Category:Burial sites of imperial Chinese families": "تصنيف:مواقع دفن أسر إمبراطورية صينية",
}

data_2 = {}

data_3 = {
    "1550 in asian women's football": "تصنيف:كرة قدم آسيوية للسيدات في 1550",
    "1520 in south american women's football": "تصنيف:كرة قدم أمريكية جنوبية للسيدات في 1520",
    "canadian women's ice hockey by league": "تصنيف:هوكي جليد كندية للسيدات حسب الدوري",
    "european women's football by country": "تصنيف:كرة قدم أوروبية للسيدات حسب البلد",
    "south american women's football": "تصنيف:كرة قدم أمريكية جنوبية للسيدات",
    "1789 in south american women's football": "تصنيف:كرة قدم أمريكية جنوبية للسيدات في 1789",
    "european national men's field hockey teams": "تصنيف:منتخبات هوكي ميدان وطنية أوروبية للرجال",
    "northern ireland national men's football teams": "تصنيف:منتخبات كرة قدم وطنية أيرلندية شمالية للرجال",
}

to_test = [
    ("test_5_data_0", data0),
    # ("test_5_data_1", data1),
    # ("test_5_data_3", data_3),
]


@pytest.mark.parametrize("category, expected", data0.items(), ids=data0.keys())
def test_5_data_0(category: str, expected: str) -> None:
    """
    pytest tests/event_lists/importants/test_5_important.py::test_5_data_0
    """
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
def test_5_data_1(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("category, expected", data_3.items(), ids=data_3.keys())
def test_5_data_3(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)

    # dump_diff_text(expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#
import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats.main_processers.main_resolve import resolve_label_ar

data_2 = {
    # NEED FIXING
    "2020 Chinese Taipei international footballers from Hong Kong": "لاعبو منتخب تايبيه الصينية لكرة القدم من هونغ كونغ في 2020",
    "14th-century writers from Crown of Aragon": "كتاب من تاج أرغون في القرن 14",
    "14th-century writers from the Crown of Aragon": "كتاب من تاج أرغون في القرن 14",
}


@pytest.mark.parametrize("category, expected", data_2.items(), ids=data_2.keys())
@pytest.mark.skip2
def test_fix_in_min_2(category: str, expected: str) -> None:
    label = resolve_label_ar(category, fix_label=False)
    assert label == expected



#
import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data_1 = {
    # "Category:Fenerbahçe women's basketball players": "تصنيف:لاعبات فنربخشة لكرة السلة للسيدات",
}

data_2 = {
    "Category:Women's England Hockey League players": "تصنيف:لاعبات الدوري الإنجليزي للهوكي للسيدات",
    "Category:2022 Women's Africa Cup of Nations players": "تصنيف:لاعبات كأس الأمم الإفريقية للسيدات 2022",
    "Category:2023 FIFA Women's World Cup players": "تصنيف:لاعبات كأس العالم لكرة القدم للسيدات 2023",
    "Category:2024 Women's Africa Cup of Nations players": "تصنيف:لاعبات كأس الأمم الإفريقية للسيدات 2024",
    "Category:Armenian women's volleyball players": "تصنيف:لاعبات كرة طائرة أرمنيات",
    "Category:Association football players by women's under-20 national team": "تصنيف:لاعبات كرة قدم حسب المنتخب الوطني للسيدات تحت 20 سنة",
    "Category:Association football players by women's under-21 national team": "تصنيف:لاعبات كرة قدم حسب المنتخب الوطني للسيدات تحت 21 سنة",
    "Category:Association football players by women's under-23 national team": "تصنيف:لاعبات كرة قدم حسب المنتخب الوطني للسيدات تحت 23 سنة",
    "Category:Basketball players by women's national team": "تصنيف:لاعبات كرة سلة حسب منتخب السيدات الوطني",
    "Category:Canada women's national basketball team players": "تصنيف:لاعبات منتخب كندا لكرة السلة للسيدات",
    "Category:Chinese Taipei women's national basketball team players": "تصنيف:لاعبات منتخب تايبيه الصينية لكرة السلة للسيدات",
    "Category:Colombian women's volleyball players": "تصنيف:لاعبات كرة طائرة كولومبيات",
    "Category:European Women's Hockey League players": "تصنيف:لاعبات الدوري الأوروبي للهوكي للسيدات",
    "Category:Expatriate women's futsal players in Kuwait": "تصنيف:لاعبات كرة صالات مغتربات في الكويت",
    "Category:Expatriate women's futsal players in the Maldives": "تصنيف:لاعبات كرة صالات مغتربات في جزر المالديف",
    "Category:Female handball players in Turkey by club": "تصنيف:لاعبات كرة يد في تركيا حسب النادي",
    "Category:Galatasaray S.K. (women's basketball) players": "تصنيف:لاعبات نادي غلطة سراي لكرة السلة للسيدات",
    "Category:Handball players by women's national team": "تصنيف:لاعبات كرة يد حسب منتخب السيدات الوطني",
    "Category:Ireland women's national basketball team players": "تصنيف:لاعبات منتخب أيرلندا لكرة السلة للسيدات",
    "Category:Ireland women's national basketball team": "تصنيف:منتخب أيرلندا لكرة السلة للسيدات",
    "Category:Ireland women's national field hockey team coaches": "تصنيف:مدربو منتخب أيرلندا لهوكي الميدان للسيدات",
    "Category:Ireland women's national field hockey team": "تصنيف:منتخب أيرلندا لهوكي الميدان للسيدات",
    "Category:Ireland women's national rugby sevens team": "تصنيف:منتخب أيرلندا لسباعيات الرجبي للسيدات",
    "Category:Ireland women's national rugby union team coaches": "تصنيف:مدربو منتخب أيرلندا لاتحاد الرجبي للسيدات",
    "Category:Ireland women's national rugby union team": "تصنيف:منتخب أيرلندا لاتحاد الرجبي للسيدات",
    "Category:Israeli women's basketball players": "تصنيف:لاعبات كرة سلة إسرائيليات",
    "Category:Italian women's futsal players": "تصنيف:لاعبات كرة صالات إيطاليات",
    "Category:Kyrgyzstani women's basketball players": "تصنيف:لاعبات كرة سلة قيرغيزستانيات",
    "Category:Kyrgyzstani women's volleyball players": "تصنيف:لاعبات كرة طائرة قيرغيزستانيات",
    "Category:New Zealand women's national rugby league team players": "تصنيف:لاعبات منتخب نيوزيلندا لدوري الرجبي للسيدات",
    "Category:Northern Ireland women's national football team": "تصنيف:منتخب أيرلندا الشمالية لكرة القدم للسيدات",
    "Category:Northern Ireland women's national football teams": "تصنيف:منتخبات كرة قدم وطنية أيرلندية شمالية للسيدات",
    "Category:Republic of Ireland association football leagues": "تصنيف:دوريات كرة القدم الأيرلندية",
    "Category:Republic of Ireland women's association football": "تصنيف:كرة قدم أيرلندية للسيدات",
    "Category:Republic of Ireland women's association footballers": "تصنيف:لاعبات كرة قدم أيرلنديات",
    "Category:Republic of Ireland women's international footballers": "تصنيف:لاعبات كرة قدم دوليات أيرلنديات",
    "Category:Republic of Ireland women's international rugby union players": "تصنيف:لاعبات اتحاد رجبي دوليات من جمهورية أيرلندا",
    "Category:Republic of Ireland women's national football team managers": "تصنيف:مدربو منتخب جمهورية أيرلندا لكرة القدم للسيدات",
    "Category:Republic of Ireland women's national football team navigational boxes": "تصنيف:صناديق تصفح منتخب جمهورية أيرلندا لكرة القدم للسيدات",
    "Category:Republic of Ireland women's national football team": "تصنيف:منتخب جمهورية أيرلندا لكرة القدم للسيدات",
    "Category:Republic of Ireland women's national football teams": "تصنيف:منتخبات كرة قدم وطنية أيرلندية للسيدات",
    "Category:Republic of Ireland women's youth international footballers": "تصنيف:لاعبات منتخب جمهورية أيرلندا لكرة القدم للشابات",
    "Category:Rugby league players by women's national team": "تصنيف:لاعبات دوري رجبي حسب منتخب السيدات الوطني",
    "Category:Rugby union players by women's national team": "تصنيف:لاعبات اتحاد رجبي حسب منتخب السيدات الوطني",
    "Category:Scottish women's basketball players": "تصنيف:لاعبات كرة سلة إسكتلنديات",
    "Category:Surinamese women's basketball players": "تصنيف:لاعبات كرة سلة سوريناميات",
    "Category:Turkey women's national basketball team players": "تصنيف:لاعبات منتخب تركيا لكرة السلة للسيدات",
    "Category:UEFA Women's Euro 2017 players": "تصنيف:لاعبات بطولة أمم أوروبا لكرة القدم للسيدات 2017",
    "Category:UEFA Women's Euro 2022 players": "تصنيف:لاعبات بطولة أمم أوروبا لكرة القدم للسيدات 2022",
    "Category:UEFA Women's Euro 2025 players": "تصنيف:لاعبات بطولة أمم أوروبا لكرة القدم للسيدات 2025",
    "Category:Victorian Women's Football League players": "تصنيف:لاعبات الدوري الفيكتوري لكرة القدم للسيدات",
    "Category:Volleyball players by women's national team": "تصنيف:لاعبات كرة طائرة حسب منتخب السيدات الوطني",
    "Category:Women's Africa Cup of Nations players": "تصنيف:لاعبات كأس الأمم الإفريقية للسيدات",
    "Category:Women's basketball players in the United States by league": "تصنيف:لاعبات كرة سلة في الولايات المتحدة حسب الدوري",
    "Category:Women's Chinese Basketball Association players": "تصنيف:لاعبات الرابطة الصينية لكرة السلة للسيدات",
    "Category:Women's field hockey players in England": "تصنيف:لاعبات هوكي ميدان في إنجلترا",
    "Category:Women's field hockey players in Ireland": "تصنيف:لاعبات هوكي ميدان في أيرلندا",
    "Category:Women's futsal players in Kuwait": "تصنيف:لاعبات كرة صالات في الكويت",
    "Category:Women's futsal players in the Maldives": "تصنيف:لاعبات كرة صالات في جزر المالديف",
    "Category:Women's handball players": "تصنيف:لاعبات كرة يد",
    "Category:Women's hockey players": "تصنيف:لاعبات هوكي",
    "Category:Women's Irish Hockey League players": "تصنيف:لاعبات الدوري الأيرلندي للهوكي للسيدات",
    "Category:Women's Korean Basketball League players": "تصنيف:لاعبات الدوري الكوري لكرة السلة للسيدات",
    "Category:Women's lacrosse players": "تصنيف:لاعبات لاكروس",
    "Category:Women's National Basketball Association players from Belgium": "تصنيف:لاعبات الاتحاد الوطني لكرة السلة للسيدات من بلجيكا",
    "Category:Women's National Basketball Association players from Croatia": "تصنيف:لاعبات الاتحاد الوطني لكرة السلة للسيدات من كرواتيا",
    "Category:Women's National Basketball Association players from Serbia": "تصنيف:لاعبات الاتحاد الوطني لكرة السلة للسيدات من صربيا",
    "Category:Women's National Basketball Association players": "تصنيف:لاعبات الاتحاد الوطني لكرة السلة للسيدات",
    "Category:Women's National Basketball League players": "تصنيف:لاعبات الدوري الوطني لكرة السلة للسيدات",
    "Category:Women's National Basketball League teams": "تصنيف:فرق الدوري الوطني لكرة السلة للسيدات",
    "Category:Women's National Basketball League": "تصنيف:الدوري الوطني لكرة السلة للسيدات",
    "Category:Women's soccer players in Australia by competition": "تصنيف:لاعبات كرة قدم في أستراليا حسب المنافسة",
}
data_3 = {}
data_4 = {}

to_test = [
    ("test_womens_players_1", data_1),
    ("test_womens_players_2", data_2),
    ("test_womens_players_3", data_3),
    ("test_womens_ireland_4", data_4),
]


@pytest.mark.parametrize("category, expected", data_2.items(), ids=data_2.keys())
@pytest.mark.fast
def test_womens_players_2(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)

    # dump_diff_text(expected, diff_result, name)

    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
